@@ -2,7 +2,8 @@
 
 static int counter = 0;
 
-LSP::DidChangeTextDocumentRequest::DidChangeTextDocumentRequest(const wxFileName& filename, const wxString& fileContent)
+LSP::DidChangeTextDocumentRequest::DidChangeTextDocumentRequest(const wxFileName& filename,
+                                                                const std::string& fileContent)
 {
     SetMethod("textDocument/didChange");
     m_params.reset(new DidChangeTextDocumentParams());
