@@ -14,15 +14,16 @@ LSP::GotoDeclarationRequest::GotoDeclarationRequest(const wxFileName& filename,
 
 LSP::GotoDeclarationRequest::~GotoDeclarationRequest() {}
 
-void LSP::GotoDeclarationRequest::OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner)
+void LSP::GotoDeclarationRequest::OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner,
+                                             IPathConverter::Ptr_t pathConverter)
 {
     JSONItem result = response.Get("result");
     if(!result.isOk()) { return; }
     LSP::Location loc;
     if(result.isArray()) {
-        loc.FromJSON(result.arrayItem(0));
+        loc.FromJSON(result.arrayItem(0), pathConverter);
     } else {
-        loc.FromJSON(result);
+        loc.FromJSON(result, pathConverter);
     }
 
     // We send the same event for declaraion as we do for definition
