@@ -14,15 +14,16 @@ LSP::GotoDefinitionRequest::GotoDefinitionRequest(const wxFileName& filename, si
 
 LSP::GotoDefinitionRequest::~GotoDefinitionRequest() {}
 
-void LSP::GotoDefinitionRequest::OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner)
+void LSP::GotoDefinitionRequest::OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner,
+                                            IPathConverter::Ptr_t pathConverter)
 {
     JSONItem result = response.Get("result");
     if(!result.isOk()) { return; }
     LSP::Location loc;
     if(result.isArray()) {
-        loc.FromJSON(result.arrayItem(0));
+        loc.FromJSON(result.arrayItem(0), pathConverter);
     } else {
-        loc.FromJSON(result);
+        loc.FromJSON(result, pathConverter);
     }
 
     if(!loc.GetUri().IsEmpty()) {
