@@ -1,8 +1,9 @@
 #ifndef JSONObject_H
 #define JSONObject_H
 
-#include "codelite_exports.h"
 #include "JSON.h"
+#include "codelite_exports.h"
+#include "IPathConverter.hpp"
 
 namespace LSP
 {
@@ -14,8 +15,8 @@ class WXDLLIMPEXP_CL Serializable
 public:
     Serializable() {}
     virtual ~Serializable() {}
-    virtual JSONItem ToJSON(const wxString& name) const = 0;
-    virtual void FromJSON(const JSONItem& json) = 0;
+    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const = 0;
+    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter) = 0;
 };
 
 };     // namespace LSP
