@@ -5,6 +5,7 @@
 #include "JSONObject.h"
 #include "JSON.h"
 #include <string>
+#include "IPathConverter.hpp"
 
 namespace LSP
 {
@@ -18,13 +19,13 @@ public:
 public:
     Message();
     virtual ~Message();
-    virtual JSONItem ToJSON(const wxString& name) const;
-    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
 
     /**
      * @brief serialize this message into string
      */
-    virtual std::string ToString() const = 0;
+    virtual std::string ToString(IPathConverter::Ptr_t pathConverter) const = 0;
 
     template <typename T> T* As() const { return dynamic_cast<T*>(const_cast<Message*>(this)); }
 };
