@@ -1,5 +1,5 @@
-#include "SignatureHelpRequest.h"
 #include "LSP/LSPEvent.h"
+#include "SignatureHelpRequest.h"
 
 LSP::SignatureHelpRequest::SignatureHelpRequest(const wxFileName& filename, size_t line, size_t column)
     : m_filename(filename)
@@ -14,13 +14,14 @@ LSP::SignatureHelpRequest::SignatureHelpRequest(const wxFileName& filename, size
 
 LSP::SignatureHelpRequest::~SignatureHelpRequest() {}
 
-void LSP::SignatureHelpRequest::OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner)
+void LSP::SignatureHelpRequest::OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner,
+                                           IPathConverter::Ptr_t pathConverter)
 {
     if(!response.Has("result")) { return; }
     JSONItem res = response.Get("result");
     LSP::SignatureHelp sh;
-    sh.FromJSON(res);
-    
+    sh.FromJSON(res, pathConverter);
+
     LSPEvent event(wxEVT_LSP_SIGNATURE_HELP);
     event.SetSignatureHelp(sh);
     owner->AddPendingEvent(event);
