@@ -11,3 +11,7 @@ bool PHPEntityKeyword::Is(eEntityType type) const { return type == kEntityTypeKe
 void PHPEntityKeyword::PrintStdout(int indent) const { wxUnusedVar(indent); }
 void PHPEntityKeyword::Store(PHPLookupTable* lookup) { wxUnusedVar(lookup); }
 wxString PHPEntityKeyword::Type() const { return ""; }
+
+void PHPEntityKeyword::FromJSON(const JSONItem& json) { BaseFromJSON(json); }
+
+JSONItem PHPEntityKeyword::ToJSON() const { return BaseToJSON("k"); }
