@@ -30,16 +30,16 @@
 #include <algorithm>
 #include "cl_standard_paths.h"
 
-#define ADD_OBJ_IF_NOT_EXISTS(parent, objName)                \
-    if(!parent.hasNamedObject(objName)) {                     \
+#define ADD_OBJ_IF_NOT_EXISTS(parent, objName)          \
+    if(!parent.hasNamedObject(objName)) {               \
         JSONItem obj = JSONItem::createObject(objName); \
-        parent.append(obj);                                   \
+        parent.append(obj);                             \
     }
 
-#define ADD_ARR_IF_NOT_EXISTS(parent, arrName)               \
-    if(!parent.hasNamedObject(arrName)) {                    \
+#define ADD_ARR_IF_NOT_EXISTS(parent, arrName)         \
+    if(!parent.hasNamedObject(arrName)) {              \
         JSONItem arr = JSONItem::createArray(arrName); \
-        parent.append(arr);                                  \
+        parent.append(arr);                            \
     }
 
 clConfig::clConfig(const wxString& filename)
@@ -48,14 +48,15 @@ clConfig::clConfig(const wxString& filename)
         m_filename = filename;
     } else {
         m_filename = clStandardPaths::Get().GetUserDataDir() + wxFileName::GetPathSeparator() + "config" +
-            wxFileName::GetPathSeparator() + filename;
+                     wxFileName::GetPathSeparator() + filename;
     }
-    m_filename.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
+
 
     if(m_filename.FileExists()) {
         m_root = new JSON(m_filename);
 
     } else {
+        if(!m_filename.DirExists()) { m_filename.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL); }
         m_root = new JSON(cJSON_Object);
     }
 
@@ -136,9 +137,7 @@ void clConfig::SetWorkspaceTabOrder(const wxArrayString& tabs, int selected)
 
 void clConfig::DoDeleteProperty(const wxString& property)
 {
-    if(m_root->toElement().hasNamedObject(property)) {
-        m_root->toElement().removeProperty(property);
-    }
+    if(m_root->toElement().hasNamedObject(property)) { m_root->toElement().removeProperty(property); }
 }
 
 bool clConfig::ReadItem(clConfigItem* item, const wxString& differentName)
@@ -182,8 +181,7 @@ wxArrayString clConfig::MergeArrays(const wxArrayString& arr1, const wxArrayStri
     return output;
 }
 
-wxStringMap_t clConfig::MergeStringMaps(
-    const wxStringMap_t& map1, const wxStringMap_t& map2) const
+wxStringMap_t clConfig::MergeStringMaps(const wxStringMap_t& map1, const wxStringMap_t& map2) const
 {
     wxStringMap_t output;
     output.insert(map1.begin(), map1.end());
@@ -213,9 +211,7 @@ JSONItem clConfig::GetGeneralSetting()
 void clConfig::Write(const wxString& name, bool value)
 {
     JSONItem general = GetGeneralSetting();
-    if(general.hasNamedObject(name)) {
-        general.removeProperty(name);
-    }
+    if(general.hasNamedObject(name)) { general.removeProperty(name); }
 
     general.addProperty(name, value);
     Save();
@@ -224,9 +220,7 @@ void clConfig::Write(const wxString& name, bool value)
 bool clConfig::Read(const wxString& name, bool defaultValue)
 {
     JSONItem general = GetGeneralSetting();
-    if(general.namedObject(name).isBool()) {
-        return general.namedObject(name).toBool();
-    }
+    if(general.namedObject(name).isBool()) { return general.namedObject(name).toBool(); }
 
     return defaultValue;
 }
@@ -234,9 +228,7 @@ bool clConfig::Read(const wxString& name, bool defaultValue)
 void clConfig::Write(const wxString& name, int value)
 {
     JSONItem general = GetGeneralSetting();
-    if(general.hasNamedObject(name)) {
-        general.removeProperty(name);
-    }
+    if(general.hasNamedObject(name)) { general.removeProperty(name); }
 
     general.addProperty(name, value);
     Save();
@@ -251,9 +243,7 @@ int clConfig::Read(const wxString& name, int defaultValue)
 void clConfig::Write(const wxString& name, const wxString& value)
 {
     JSONItem general = GetGeneralSetting();
-    if(general.hasNamedObject(name)) {
-        general.removeProperty(name);
-    }
+    if(general.hasNamedObject(name)) { general.removeProperty(name); }
 
     general.addProperty(name, value);
     Save();
@@ -262,9 +252,7 @@ void clConfig::Write(const wxString& name, const wxString& value)
 wxString clConfig::Read(const wxString& name, const wxString& defaultValue)
 {
     JSONItem general = GetGeneralSetting();
-    if(general.namedObject(name).isString()) {
-        return general.namedObject(name).toString();
-    }
+    if(general.namedObject(name).isString()) { return general.namedObject(name).toString(); }
 
     return defaultValue;
 }
@@ -274,9 +262,7 @@ int clConfig::GetAnnoyingDlgAnswer(const wxString& name, int defaultValue)
     if(m_root->toElement().hasNamedObject("AnnoyingDialogsAnswers")) {
 
         JSONItem element = m_root->toElement().namedObject("AnnoyingDialogsAnswers");
-        if(element.hasNamedObject(name)) {
-            return element.namedObject(name).toInt(defaultValue);
-        }
+        if(element.hasNamedObject(name)) { return element.namedObject(name).toInt(defaultValue); }
     }
     return defaultValue;
 }
@@ -289,9 +275,7 @@ void clConfig::SetAnnoyingDlgAnswer(const wxString& name, int value)
     }
 
     JSONItem element = m_root->toElement().namedObject("AnnoyingDialogsAnswers");
-    if(element.hasNamedObject(name)) {
-        element.removeProperty(name);
-    }
+    if(element.hasNamedObject(name)) { element.removeProperty(name); }
     element.addProperty(name, value);
     Save();
 }
@@ -307,9 +291,7 @@ void clConfig::SetQuickFindSearchItems(const wxArrayString& items)
 {
     ADD_OBJ_IF_NOT_EXISTS(m_root->toElement(), "QuickFindBar");
     JSONItem quickFindBar = m_root->toElement().namedObject("QuickFindBar");
-    if(quickFindBar.hasNamedObject("SearchHistory")) {
-        quickFindBar.removeProperty("SearchHistory");
-    }
+    if(quickFindBar.hasNamedObject("SearchHistory")) { quickFindBar.removeProperty("SearchHistory"); }
     quickFindBar.addProperty("SearchHistory", items);
     Save();
 }
@@ -318,9 +300,7 @@ void clConfig::SetQuickFindReplaceItems(const wxArrayString& items)
 {
     ADD_OBJ_IF_NOT_EXISTS(m_root->toElement(), "QuickFindBar");
     JSONItem quickFindBar = m_root->toElement().namedObject("QuickFindBar");
-    if(quickFindBar.hasNamedObject("ReplaceHistory")) {
-        quickFindBar.removeProperty("ReplaceHistory");
-    }
+    if(quickFindBar.hasNamedObject("ReplaceHistory")) { quickFindBar.removeProperty("ReplaceHistory"); }
     quickFindBar.addProperty("ReplaceHistory", items);
     Save();
 }
@@ -367,9 +347,7 @@ void clConfig::AddQuickFindSearchItem(const wxString& str)
 
     // Update the array
     int where = items.Index(str);
-    if(where != wxNOT_FOUND) {
-        items.RemoveAt(where);
-    }
+    if(where != wxNOT_FOUND) { items.RemoveAt(where); }
     items.Insert(str, 0);
 
     // Reudce to size to max of 20
@@ -402,18 +380,14 @@ wxArrayString clConfig::GetQuickFindSearchItems() const
 wxArrayString clConfig::Read(const wxString& name, const wxArrayString& defaultValue)
 {
     JSONItem general = GetGeneralSetting();
-    if(general.hasNamedObject(name)) {
-        return general.namedObject(name).toArrayString();
-    }
+    if(general.hasNamedObject(name)) { return general.namedObject(name).toArrayString(); }
     return defaultValue;
 }
 
 void clConfig::Write(const wxString& name, const wxArrayString& value)
 {
     JSONItem general = GetGeneralSetting();
-    if(general.hasNamedObject(name)) {
-        general.removeProperty(name);
-    }
+    if(general.hasNamedObject(name)) { general.removeProperty(name); }
 
     general.addProperty(name, value);
     Save();
@@ -424,9 +398,7 @@ void clConfig::DoAddRecentItem(const wxString& propName, const wxString& filenam
     wxArrayString recentItems = DoGetRecentItems(propName);
 
     // Prepend the item
-    if(recentItems.Index(filename) != wxNOT_FOUND) {
-        recentItems.Remove(filename);
-    }
+    if(recentItems.Index(filename) != wxNOT_FOUND) { recentItems.Remove(filename); }
 
     if(!wxFileName(filename).FileExists()) {
         // Don't add non existing file
@@ -443,25 +415,19 @@ void clConfig::DoAddRecentItem(const wxString& propName, const wxString& filenam
     // Remove non existing items
     wxArrayString existingFiles;
     for(size_t i = 0; i < recentItems.size(); ++i) {
-        if(wxFileName(recentItems.Item(i)).FileExists()) {
-            existingFiles.Add(recentItems.Item(i));
-        }
+        if(wxFileName(recentItems.Item(i)).FileExists()) { existingFiles.Add(recentItems.Item(i)); }
     }
     recentItems.swap(existingFiles);
 
     // Remove old node if exists
     JSONItem e = m_root->toElement();
-    if(e.hasNamedObject(propName)) {
-        e.removeProperty(propName);
-    }
+    if(e.hasNamedObject(propName)) { e.removeProperty(propName); }
 
     // append new property
     e.addProperty(propName, recentItems);
 
     // update the cache
-    if(m_cacheRecentItems.count(propName)) {
-        m_cacheRecentItems.erase(propName);
-    }
+    if(m_cacheRecentItems.count(propName)) { m_cacheRecentItems.erase(propName); }
 
     m_cacheRecentItems.insert(std::make_pair(propName, recentItems));
     m_root->save(m_filename);
@@ -470,14 +436,10 @@ void clConfig::DoAddRecentItem(const wxString& propName, const wxString& filenam
 void clConfig::DoClearRecentItems(const wxString& propName)
 {
     JSONItem e = m_root->toElement();
-    if(e.hasNamedObject(propName)) {
-        e.removeProperty(propName);
-    }
+    if(e.hasNamedObject(propName)) { e.removeProperty(propName); }
     m_root->save(m_filename);
     // update the cache
-    if(m_cacheRecentItems.count(propName)) {
-        m_cacheRecentItems.erase(propName);
-    }
+    if(m_cacheRecentItems.count(propName)) { m_cacheRecentItems.erase(propName); }
 }
 
 wxArrayString clConfig::DoGetRecentItems(const wxString& propName) const
@@ -490,9 +452,7 @@ wxArrayString clConfig::DoGetRecentItems(const wxString& propName) const
 
     } else {
         JSONItem e = m_root->toElement();
-        if(e.hasNamedObject(propName)) {
-            recentItems = e.namedObject(propName).toArrayString();
-        }
+        if(e.hasNamedObject(propName)) { recentItems = e.namedObject(propName).toArrayString(); }
     }
     return recentItems;
 }
@@ -522,9 +482,7 @@ void clConfig::Write(const wxString& name, const wxFont& value)
     font.addProperty("italic", (value.GetStyle() == wxFONTSTYLE_ITALIC));
 
     JSONItem general = GetGeneralSetting();
-    if(general.hasNamedObject(name)) {
-        general.removeProperty(name);
-    }
+    if(general.hasNamedObject(name)) { general.removeProperty(name); }
     general.append(font);
     Save();
 }
@@ -533,9 +491,7 @@ wxColour clConfig::Read(const wxString& name, const wxColour& defaultValue)
 {
     wxString strValue;
     strValue = Read(name, wxString());
-    if(strValue.IsEmpty()) {
-        return defaultValue;
-    }
+    if(strValue.IsEmpty()) { return defaultValue; }
     wxColour col(strValue);
     return col;
 }
