@@ -38,6 +38,8 @@ wxDEFINE_EVENT(wxEVT_CMD_PROJ_SETTINGS_SAVED, clProjectSettingsEvent);
 wxDEFINE_EVENT(wxEVT_CMD_EXECUTE_ACTIVE_PROJECT, clExecuteEvent);
 wxDEFINE_EVENT(wxEVT_CMD_IS_PROGRAM_RUNNING, clExecuteEvent);
 wxDEFINE_EVENT(wxEVT_CMD_STOP_EXECUTED_PROGRAM, clExecuteEvent);
+wxDEFINE_EVENT(wxEVT_PROGRAM_STARTED, clExecuteEvent);
+wxDEFINE_EVENT(wxEVT_PROGRAM_TERMINATED, clExecuteEvent);
 wxDEFINE_EVENT(wxEVT_BUILD_STARTED, clBuildEvent);
 wxDEFINE_EVENT(wxEVT_BUILD_ENDED, clBuildEvent);
 wxDEFINE_EVENT(wxEVT_BUILD_STARTING, clBuildEvent);
@@ -56,6 +58,8 @@ wxDEFINE_EVENT(wxEVT_DEBUG_ENDING, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DEBUG_ENDED, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DEBUGGER_REFRESH_PANE, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DEBUGGER_SET_MEMORY, clDebugEvent);
+wxDEFINE_EVENT(wxEVT_QUICK_DEBUG_DLG_SHOWING, clDebugEvent);
+wxDEFINE_EVENT(wxEVT_QUICK_DEBUG_DLG_DISMISSED_OK, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DEBUG_EDITOR_LOST_CONTROL, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_DEBUG_EDITOR_GOT_CONTROL, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_CC_CODE_COMPLETE, clCodeCompletionEvent);
@@ -179,3 +183,8 @@ wxDEFINE_EVENT(wxEVT_NAVBAR_SCOPE_MENU_SHOWING, clContextMenuEvent);
 wxDEFINE_EVENT(wxEVT_NAVBAR_SCOPE_MENU_SELECTION_MADE, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_MARKER_CHANGED, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_INFO_BAR_BUTTON, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_BUILD_CUSTOM_TARGETS_MENU_SHOWING, clContextMenuEvent);
+wxDEFINE_EVENT(wxEVT_SOURCE_CONTROL_PUSHED, clSourceControlEvent);
+wxDEFINE_EVENT(wxEVT_SOURCE_CONTROL_COMMIT_LOCALLY, clSourceControlEvent);
+wxDEFINE_EVENT(wxEVT_SOURCE_CONTROL_RESET_FILES, clSourceControlEvent);
+wxDEFINE_EVENT(wxEVT_SOURCE_CONTROL_PULLED, clSourceControlEvent);
