@@ -39,31 +39,26 @@ wxCriticalSection FileLogger::m_cs;
 
 FileLogger::FileLogger(int requestedVerbo)
     : _requestedLogLevel(requestedVerbo)
-    , m_fp(NULL)
+    , m_fp(nullptr)
 {
-    m_fp = wxFopen(m_logfile, wxT("a+"));
 }
 
 FileLogger::~FileLogger()
 {
-    if(m_fp) {
-        // flush any content that remain
-        Flush();
-        fclose(m_fp);
-        m_fp = NULL;
-    }
+    // flush any content that remain
+    Flush();
 }
 
 void FileLogger::AddLogLine(const wxString& msg, int verbosity)
 {
-    if(msg.IsEmpty()) return;
-    if((m_verbosity >= verbosity) && m_fp) {
+    if(msg.IsEmpty()) { return; }
+    if((m_verbosity >= verbosity)) {
         wxString formattedMsg = Prefix(verbosity);
         formattedMsg << " " << msg;
         formattedMsg.Trim().Trim(false);
         formattedMsg << wxT("\n");
-        wxFprintf(m_fp, wxT("%s"), formattedMsg.c_str());
-        fflush(m_fp);
+        if(!m_buffer.empty() && (m_buffer.Last() != '\n')) { m_buffer << "\n"; }
+        m_buffer << formattedMsg;
     }
 }
 
@@ -136,47 +131,54 @@ void FileLogger::AddLogLine(const wxArrayString& arr, int verbosity)
 void FileLogger::Flush()
 {
     if(m_buffer.IsEmpty()) { return; }
-    wxFprintf(m_fp, "%s\n", m_buffer);
-    fflush(m_fp);
+    if(!m_fp) { m_fp = wxFopen(m_logfile, wxT("a+")); }
+
+    if(m_fp) {
+        wxFprintf(m_fp, "%s\n", m_buffer);
+        fclose(m_fp);
+        m_fp = nullptr;
+    }
     m_buffer.Clear();
 }
 
 wxString FileLogger::Prefix(int verbosity)
 {
-    wxString prefix;
-    timeval tim;
-    gettimeofday(&tim, NULL);
-    int ms = (int)tim.tv_usec / 1000.0;
+    if(verbosity <= m_verbosity) {
+        wxString prefix;
+        timeval tim;
+        gettimeofday(&tim, NULL);
+        int ms = (int)tim.tv_usec / 1000.0;
 
-    wxString msStr = wxString::Format(wxT("%03d"), ms);
-    prefix << wxT("[") << wxDateTime::Now().FormatISOTime() << wxT(":") << msStr;
-    switch(verbosity) {
-    case System:
-        prefix << wxT(" SYS]");
-        break;
+        wxString msStr = wxString::Format(wxT("%03d"), ms);
+        prefix << wxT("[") << wxDateTime::Now().FormatISOTime() << wxT(":") << msStr;
+        switch(verbosity) {
+        case System:
+            prefix << wxT(" SYS]");
+            break;
 
-    case Error:
-        prefix << wxT(" ERR]");
-        break;
+        case Error:
+            prefix << wxT(" ERR]");
+            break;
 
-    case Warning:
-        prefix << wxT(" WRN]");
-        break;
+        case Warning:
+            prefix << wxT(" WRN]");
+            break;
 
-    case Dbg:
-        prefix << wxT(" DBG]");
-        break;
+        case Dbg:
+            prefix << wxT(" DBG]");
+            break;
 
-    case Developer:
-        prefix << wxT(" DVL]");
-        break;
+        case Developer:
+            prefix << wxT(" DVL]");
+            break;
+        }
+
+        wxString thread_name = GetCurrentThreadName();
+        if(!thread_name.IsEmpty()) { prefix << " [" << thread_name << "]"; }
+        return prefix;
+    } else {
+        return wxEmptyString;
     }
-    
-    wxString thread_name = GetCurrentThreadName();
-    if(!thread_name.IsEmpty()) {
-        prefix << " [" << thread_name << "]";
-    }
-    return prefix;
 }
 
 wxString FileLogger::GetCurrentThreadName()
