@@ -30,6 +30,7 @@
 #include "crawler_include.h"
 #include "ctags_manager.h"
 #include "file_logger.h"
+#include "fileextmanager.h"
 #include "fileutils.h"
 #include "istorage.h"
 #include "parse_thread.h"
@@ -37,12 +38,14 @@
 #include "pptable.h"
 #include "precompiled_header.h"
 #include "tags_storage_sqlite3.h"
+#include "wxStringHash.h"
+#include <functional>
 #include <set>
 #include <tags_options_data.h>
+#include <unordered_set>
 #include <wx/ffile.h>
 #include <wx/stopwatch.h>
 #include <wx/tokenzr.h>
-#include "fileextmanager.h"
 
 #define DEBUG_MESSAGE(x) CL_DEBUG1(x.c_str())
 
@@ -89,7 +92,9 @@ static const wxString& WriteCodeLiteCCHelperFile()
         filepath = tmpFile.GetFullPath();
     }
 
-    if(wxFileName::FileExists(filepath)) { return filepath; }
+    if(wxFileName::FileExists(filepath)) {
+        return filepath;
+    }
     FileUtils::WriteFileContent(wxFileName(filepath), buffer);
     return filepath;
 }
@@ -103,24 +108,42 @@ ParseThread::~ParseThread() {}
 
 void ParseThread::ProcessRequest(ThreadRequest* request)
 {
+    clConfig config("code-completion.conf");
+    config.ReadItem(&m_tod);
+
     // request is delete by the parent WorkerThread after this method is completed
     ParseRequest* req = (ParseRequest*)request;
     FileLogger::RegisterThread(wxThread::GetCurrentId(), "C++ Parser Thread");
 
+    // Exclude all files found in the exclude folders
+    wxArrayString inc, exc;
+    GetSearchPaths(inc, exc);
+
+    std::function<bool(const wxString&)> fnIsExcluded = [&](const wxString& file_path) -> bool {
+        for(const wxString& dirpath : exc) {
+            if(file_path.StartsWith(dirpath)) {
+                clDEBUG1() << "Excluding file" << file_path;
+                return true;
+            }
+        }
+        return false;
+    };
+
     // Filter non C++ files
     if(!req->_workspaceFiles.empty()) {
         std::vector<std::string> filtered_list;
         filtered_list.reserve(req->_workspaceFiles.size());
         for(std::string& filename : req->_workspaceFiles) {
-            if(FileExtManager::IsCxxFile(wxString() << filename)) { filtered_list.push_back(std::move(filename)); }
+            wxString f = filename;
+            if(FileExtManager::IsCxxFile(f) && !fnIsExcluded(f)) {
+                filtered_list.push_back(std::move(filename));
+            }
         }
         req->_workspaceFiles.swap(filtered_list);
     }
 
-    wxArrayString inc, exc;
-    GetSearchPaths(inc, exc);
-
-    clDEBUG1() << "include paths:\n" << inc;
+    clDEBUG1() << "include paths:" << inc;
+    clDEBUG1() << "exclude paths:" << exc;
 
     switch(req->getType()) {
     case ParseRequest::PR_PARSEINCLUDES:
@@ -194,6 +217,9 @@ void ParseThread::SetSearchPaths(const wxArrayString& paths, const wxArrayString
     wxCriticalSectionLocker locker(m_cs);
     m_searchPaths.Clear();
     m_excludePaths.Clear();
+    if(paths.empty() && exlucdePaths.empty()) {
+        return;
+    }
     for(size_t i = 0; i < paths.GetCount(); i++) {
         m_searchPaths.Add(paths.Item(i).c_str());
     }
@@ -242,7 +268,8 @@ void ParseThread::ProcessSimple(ParseRequest* req)
 
     clDEBUG1() << "Parsing saved file:" << file << clEndl;
     // Skip binary file
-    if(TagsManagerST::Get()->IsBinaryFile(file)) {
+
+    if(TagsManagerST::Get()->IsBinaryFile(file, m_tod)) {
         clDEBUG1() << "File:" << file << "is binady and will be skipped" << clEndl;
         return;
     }
@@ -295,7 +322,9 @@ void ParseThread::ProcessSimple(ParseRequest* req)
 
 void ParseThread::GetFileListToParse(const wxString& filename, wxArrayString& arrFiles)
 {
-    if(!this->IsCrawlerEnabled()) { return; }
+    if(!this->IsCrawlerEnabled()) {
+        return;
+    }
 
     {
         wxCriticalSectionLocker locker(TagsManagerST::Get()->m_crawlerLocker);
@@ -317,7 +346,7 @@ void ParseThread::GetFileListToParse(const wxString& filename, wxArrayString& ar
         const wxCharBuffer cfile = filename.mb_str(wxConvUTF8);
 
         // Skip binary files
-        if(TagsManagerST::Get()->IsBinaryFile(filename)) {
+        if(TagsManagerST::Get()->IsBinaryFile(filename, m_tod)) {
             DEBUG_MESSAGE(wxString::Format(wxT("Skipping binary file %s"), filename.c_str()));
             return;
         }
@@ -349,7 +378,9 @@ void ParseThread::ParseAndStoreFiles(ParseRequest* req, const wxArrayString& arr
         wxString tags; // output
         TagsManagerST::Get()->SourceToTags(arrFiles.Item(i), tags);
 
-        if(tags.IsEmpty() == false) { DoStoreTags(tags, arrFiles.Item(i), totalSymbols, db); }
+        if(tags.IsEmpty() == false) {
+            DoStoreTags(tags, arrFiles.Item(i), totalSymbols, db);
+        }
     }
 
     DEBUG_MESSAGE(wxString(wxT("Done")));
@@ -360,7 +391,8 @@ void ParseThread::ParseAndStoreFiles(ParseRequest* req, const wxArrayString& arr
     if(req->_evtHandler) {
         wxCommandEvent e(wxEVT_PARSE_THREAD_MESSAGE);
         wxString message;
-        if(initalCount != -1) message << wxT("INFO: Found ") << initalCount << wxT(" system include files. ");
+        if(initalCount != -1)
+            message << wxT("INFO: Found ") << initalCount << wxT(" system include files. ");
         message << arrFiles.GetCount() << wxT(" needed to be parsed. Stored ") << totalSymbols
                 << wxT(" new tags to the database");
 
@@ -379,7 +411,8 @@ void ParseThread::ParseAndStoreFiles(ParseRequest* req, const wxArrayString& arr
 void ParseThread::ProcessDeleteTagsOfFiles(ParseRequest* req)
 {
     DEBUG_MESSAGE(wxString(wxT("ParseThread::ProcessDeleteTagsOfFile")));
-    if(req->_workspaceFiles.empty()) return;
+    if(req->_workspaceFiles.empty())
+        return;
 
     wxString dbfile = req->getDbfile();
     ITagsStoragePtr db(new TagsStorageSQLite());
@@ -406,12 +439,16 @@ void ParseThread::ProcessParseAndStore(ParseRequest* req)
 
     // convert the file to tags
     double maxVal = (double)req->_workspaceFiles.size();
-    if(maxVal == 0.0) { return; }
+    if(maxVal == 0.0) {
+        return;
+    }
 
     // we report every 10%
     double reportingPoint = maxVal / 100.0;
     reportingPoint = ceil(reportingPoint);
-    if(reportingPoint == 0.0) { reportingPoint = 1.0; }
+    if(reportingPoint == 0.0) {
+        reportingPoint = 1.0;
+    }
 
     ITagsStoragePtr db(new TagsStorageSQLite());
     db->OpenDatabase(dbfile);
@@ -440,7 +477,7 @@ void ParseThread::ProcessParseAndStore(ParseRequest* req)
         wxFileName curFile(wxString(req->_workspaceFiles[i].c_str(), wxConvUTF8));
 
         // Skip binary files
-        if(TagsManagerST::Get()->IsBinaryFile(curFile.GetFullPath())) {
+        if(TagsManagerST::Get()->IsBinaryFile(curFile.GetFullPath(), m_tod)) {
             DEBUG_MESSAGE(wxString::Format(wxT("Skipping binary file %s"), curFile.GetFullPath().c_str()));
             continue;
         }
@@ -499,17 +536,19 @@ void ParseThread::FindIncludedFiles(ParseRequest* req, std::set<wxString>* newSe
     wxArrayString searchPaths, excludePaths, filteredFileList;
     GetSearchPaths(searchPaths, excludePaths);
 
-    DEBUG_MESSAGE(
-        wxString::Format(wxT("Initial workspace files count is %u"), (unsigned int)req->_workspaceFiles.size()));
+    if(!req->_workspaceFiles.empty()) {
+        filteredFileList.Alloc(req->_workspaceFiles.size());
+    }
 
-    for(size_t i = 0; i < req->_workspaceFiles.size(); i++) {
+    for(size_t i = 0; i < req->_workspaceFiles.size(); ++i) {
         wxString name(req->_workspaceFiles.at(i).c_str(), wxConvUTF8);
         wxFileName fn(name);
         fn.MakeAbsolute();
-
-        if(TagsManagerST::Get()->IsBinaryFile(fn.GetFullPath())) continue;
-
-        filteredFileList.Add(fn.GetFullPath());
+        fn.Normalize();
+        wxString fullpath = fn.GetFullPath();
+        if(TagsManagerST::Get()->IsBinaryFile(fullpath, m_tod))
+            continue;
+        filteredFileList.Add(fullpath);
     }
 
     wxArrayString arrFiles;
@@ -524,20 +563,22 @@ void ParseThread::FindIncludedFiles(ParseRequest* req, std::set<wxString>* newSe
 
         for(size_t i = 0; i < searchPaths.GetCount(); i++) {
             const wxCharBuffer path = _C(searchPaths.Item(i));
-            DEBUG_MESSAGE(wxString::Format(wxT("ParseThread: Using Search Path: %s "), searchPaths.Item(i).c_str()));
+            clDEBUG1() << "Using include path:" << searchPaths.Item(i);
             fcFileOpener::Get()->AddSearchPath(path.data());
         }
 
         for(size_t i = 0; i < excludePaths.GetCount(); i++) {
             const wxCharBuffer path = _C(excludePaths.Item(i));
-            DEBUG_MESSAGE(wxString::Format(wxT("ParseThread: Using Exclude Path: %s "), excludePaths.Item(i).c_str()));
+            clDEBUG1() << "Using exclude path:" << excludePaths.Item(i);
             fcFileOpener::Get()->AddExcludePath(path.data());
         }
 
         for(size_t i = 0; i < filteredFileList.GetCount(); i++) {
             const wxCharBuffer cfile = filteredFileList.Item(i).mb_str(wxConvUTF8);
             crawlerScan(cfile.data());
-            if(TestDestroy()) { return; }
+            if(TestDestroy()) {
+                return;
+            }
         }
         newSet->insert(fcFileOpener::Get()->GetResults().begin(), fcFileOpener::Get()->GetResults().end());
     }
@@ -552,7 +593,9 @@ void ParseRequest::setTags(const wxString& tags) { _tags = tags.c_str(); }
 
 ParseRequest::ParseRequest(const ParseRequest& rhs)
 {
-    if(this == &rhs) { return; }
+    if(this == &rhs) {
+        return;
+    }
     *this = rhs;
 }
 
@@ -574,13 +617,16 @@ static ParseThread* gs_theParseThread = NULL;
 
 void ParseThreadST::Free()
 {
-    if(gs_theParseThread) { delete gs_theParseThread; }
+    if(gs_theParseThread) {
+        delete gs_theParseThread;
+    }
     gs_theParseThread = NULL;
 }
 
 ParseThread* ParseThreadST::Get()
 {
-    if(gs_theParseThread == NULL) gs_theParseThread = new ParseThread;
+    if(gs_theParseThread == NULL)
+        gs_theParseThread = new ParseThread;
     return gs_theParseThread;
 }
 
@@ -594,7 +640,8 @@ void ParseThread::ProcessSimpleNoIncludes(ParseRequest* req)
     wxArrayString filesArr;
     for(size_t i = 0; i < files.size(); i++) {
         wxString filename = wxString(files.at(i).c_str(), wxConvUTF8);
-        if(TagsManagerST::Get()->IsBinaryFile(filename)) continue;
+        if(TagsManagerST::Get()->IsBinaryFile(filename, m_tod))
+            continue;
         filesArr.Add(filename);
     }
 
@@ -663,7 +710,9 @@ void ParseThread::ProcessColourRequest(ParseRequest* req)
         wxStringSet_t tokens;
         CxxLexerToken tok;
         while(tokenizer.NextToken(tok)) {
-            if(tok.GetType() == T_IDENTIFIER) { tokens.insert(tok.GetWXString()); }
+            if(tok.GetType() == T_IDENTIFIER) {
+                tokens.insert(tok.GetWXString());
+            }
         }
 
         std::vector<wxString> tokensArr;
@@ -672,7 +721,9 @@ void ParseThread::ProcessColourRequest(ParseRequest* req)
         std::sort(tokensArr.begin(), tokensArr.end());
 
         // did we find anything?
-        if(tokensArr.empty()) { return; }
+        if(tokensArr.empty()) {
+            return;
+        }
 
         // Open the database
         ITagsStoragePtr db(new TagsStorageSQLite());
@@ -702,7 +753,9 @@ void ParseThread::ProcessColourRequest(ParseRequest* req)
 void ParseThread::ProcessSourceToTags(ParseRequest* req)
 {
     wxFileName filename(req->getFile());
-    if(TagsManagerST::Get()->IsBinaryFile(filename.GetFullPath())) { return; }
+    if(TagsManagerST::Get()->IsBinaryFile(filename.GetFullPath(), m_tod)) {
+        return;
+    }
 
     wxString strTags;
     TagsManagerST::Get()->SourceToTags(filename, strTags);
@@ -717,9 +770,9 @@ void ParseThread::ProcessSourceToTags(ParseRequest* req)
 
 void ParseThread::AddPaths(const wxArrayString& inc, const wxArrayString& exc)
 {
-    // remove all duplicates
+    // Remove all duplicates
     wxCriticalSectionLocker locker(m_cs);
-    {
+    if(!inc.IsEmpty()) {
         wxStringSet_t unique;
         wxArrayString tmp;
         for(const wxString& path : inc) {
@@ -745,8 +798,8 @@ void ParseThread::AddPaths(const wxArrayString& inc, const wxArrayString& exc)
         m_searchPaths.swap(tmp);
         std::sort(m_searchPaths.begin(), m_searchPaths.end());
     }
-    
-    {
+
+    if(!exc.IsEmpty()) {
         wxStringSet_t unique;
         wxArrayString tmp;
         for(const wxString& path : exc) {
@@ -774,4 +827,4 @@ void ParseThread::AddPaths(const wxArrayString& inc, const wxArrayString& exc)
     }
 }
 
-void ParseThread::ClearPaths() {}
+void ParseThread::ClearPaths() { SetSearchPaths({}, {}); }
