@@ -32,17 +32,42 @@ WorkerThread::WorkerThread()
 
 WorkerThread::~WorkerThread() { Stop(); }
 
+static ThreadRequest* QueueGet(std::mutex& m, std::queue<ThreadRequest*>& q, std::condition_variable& cv)
+{
+    std::unique_lock<std::mutex> lock{ m }; // acquiring the mutex
+    while(q.empty()) {
+        cv.wait(lock); // waiting to be notified of new data
+    }
+
+    ThreadRequest* req = q.front(); // moving the front element
+    q.pop();                        // which is immediately deleted
+
+    return req;
+}
+
+static void QueuePut(std::mutex& m, std::queue<ThreadRequest*>& q, std::condition_variable& cv, ThreadRequest* req)
+{
+    std::unique_lock<std::mutex> lock{ m }; // Acquires the mutex
+    q.push(req);                            // Forward the param to the
+    lock.unlock();                          // operation on the wrapped collection
+    cv.notify_one();
+}
+
 void* WorkerThread::Entry()
 {
     while(true) {
         // Did we get a request to terminate?
         if(TestDestroy()) break;
-        ThreadRequest* request = NULL;
-        if(m_queue.ReceiveTimeout(50, request) == wxMSGQUEUE_NO_ERROR) {
-            // Call user's implementation for processing request
-            ProcessRequest(request);
-            wxDELETE(request);
+
+        // Get the next entry from the queue
+        ThreadRequest* request = QueueGet(m_mutex, m_Q, m_cv);
+        if(request == nullptr) {
+            // this dummy message was sent to tell us to exit
+            break;
         }
+        // Call user's implementation for processing request
+        ProcessRequest(request);
+        wxDELETE(request);
     }
     return NULL;
 }
@@ -50,13 +75,15 @@ void* WorkerThread::Entry()
 void WorkerThread::Add(ThreadRequest* request)
 {
     if(!request) { return; }
-    m_queue.Post(request);
+    QueuePut(m_mutex, m_Q, m_cv, request);
 }
 
 void WorkerThread::Stop()
 {
     // Notify the thread to exit and
     // wait for it
+    QueuePut(m_mutex, m_Q, m_cv, nullptr); // Make sure that the thread wakes up
+
     if(IsAlive()) {
         Delete(NULL, wxTHREAD_WAIT_BLOCK);
 
@@ -71,3 +98,11 @@ void WorkerThread::Start(int priority)
     SetPriority(priority);
     Run();
 }
+
+void WorkerThread::ClearQueue()
+{
+    std::unique_lock<std::mutex> lk(m_mutex);
+    while(!m_Q.empty()) {
+        m_Q.pop();
+    }
+}
