@@ -94,8 +94,8 @@ void CodeLiteDiff::UnPlug()
 
 void CodeLiteDiff::OnNewDiff(wxCommandEvent& e)
 {
-    clDiffFrame diff(EventNotifier::Get()->TopFrame());
-    diff.ShowModal();
+    clDiffFrame* diff = new clDiffFrame(EventNotifier::Get()->TopFrame());
+    diff->Show();
 }
 
 void CodeLiteDiff::OnTabContextMenu(clContextMenuEvent& event)
@@ -164,8 +164,8 @@ void CodeLiteDiff::OnDiff(wxCommandEvent& event)
             }
         }
 
-        clDiffFrame diffView(EventNotifier::Get()->TopFrame(), m_leftFile, secondFile, tempfile);
-        diffView.ShowModal();
+        clDiffFrame* diffView = new clDiffFrame(EventNotifier::Get()->TopFrame(), m_leftFile, secondFile, tempfile);
+        diffView->Show();
     }
 }
 
