@@ -4,15 +4,20 @@
 
 class LanguageServerSettingsDlg : public LanguageServerSettingsDlgBase
 {
+    bool m_scanOnStartup = false;
+
 public:
-    LanguageServerSettingsDlg(wxWindow* parent);
+    LanguageServerSettingsDlg(wxWindow* parent, bool triggerScan);
     virtual ~LanguageServerSettingsDlg();
     void Save();
-    
+
 protected:
+    virtual void OnScan(wxCommandEvent& event);
     virtual void OnOKUI(wxUpdateUIEvent& event);
     virtual void OnDeleteLSP(wxCommandEvent& event);
     virtual void OnDeleteLSPUI(wxUpdateUIEvent& event);
     virtual void OnAddServer(wxCommandEvent& event);
+    void DoInitialize();
+    void DoScan();
 };
 #endif // LANGUAGESERVERSETTINGSDLG_H
