@@ -55,6 +55,8 @@
 #include <wx/fdrepdlg.h>
 #include <wx/regex.h>
 #include <wx/settings.h>
+#include "clFileSystemWorkspace.hpp"
+#include "clFileSystemWorkspaceConfig.hpp"
 
 #define IS_VALID_LINE(lineNumber) ((lineNumber >= 0 && lineNumber < m_view->GetLineCount()))
 #ifdef __WXMSW__
@@ -64,7 +66,7 @@
 #endif
 
 // Helper function to post an event to the frame
-void SetActive(LEditor* editor)
+void SetActive(clEditor* editor)
 {
     wxCHECK_RET(editor, wxT("Null editor parameter"));
 
@@ -102,6 +104,7 @@ NewBuildTab::NewBuildTab(wxWindow* parent)
     , m_maxlineWidth(wxNOT_FOUND)
     , m_lastLineColoured(wxNOT_FOUND)
 {
+    SetSize(wxNOT_FOUND, 400);
     m_curError = m_errorsAndWarningsList.end();
     wxBoxSizer* bs = new wxBoxSizer(wxVERTICAL);
     SetSizer(bs);
@@ -164,7 +167,7 @@ void NewBuildTab::OnBuildEnded(clCommandEvent& e)
 
     DoProcessOutput(true, false);
 
-    std::vector<LEditor*> editors;
+    std::vector<clEditor*> editors;
     clMainFrame::Get()->GetMainBook()->GetAllEditors(editors, MainBook::kGetAll_Default);
     for(size_t i = 0; i < editors.size(); i++) {
         MarkEditor(editors.at(i));
@@ -280,12 +283,15 @@ void NewBuildTab::OnBuildStarted(clCommandEvent& e)
         buildEvent.SetProjectName(bed->GetProjectName());
         buildEvent.SetConfigurationName(bed->GetConfiguration());
         EventNotifier::Get()->AddPendingEvent(buildEvent);
+    } else if(clFileSystemWorkspace::Get().IsOpen() && clFileSystemWorkspace::Get().GetSettings().GetSelectedConfig()) {
+        const wxString& cmpname = clFileSystemWorkspace::Get().GetSettings().GetSelectedConfig()->GetCompiler();
+        m_cmp = BuildSettingsConfigST::Get()->GetCompiler(cmpname);
     }
 }
 
 void NewBuildTab::OnBuildAddLine(clCommandEvent& e)
 {
-    e.Skip(); // Allways call skip..
+    e.Skip(); // Always call skip..
     m_output << e.GetString();
     DoProcessOutput(false, false);
 }
@@ -383,7 +389,7 @@ void NewBuildTab::DoClear()
     m_view->SetEditable(false);
 
     // Clear all markers from open editors
-    std::vector<LEditor*> editors;
+    std::vector<clEditor*> editors;
     clMainFrame::Get()->GetMainBook()->GetAllEditors(editors, MainBook::kGetAll_Default);
     for(size_t i = 0; i < editors.size(); i++) {
         editors.at(i)->DelAllCompilerMarkers();
@@ -392,7 +398,7 @@ void NewBuildTab::DoClear()
     m_curError = m_errorsAndWarningsList.end();
 }
 
-void NewBuildTab::MarkEditor(LEditor* editor)
+void NewBuildTab::MarkEditor(clEditor* editor)
 {
     if(!editor) return;
 
@@ -436,16 +442,14 @@ void NewBuildTab::MarkEditor(LEditor* editor)
         if(!text.IsEmpty()) {
             if(bli && (bli->GetSeverity() == SV_ERROR || bli->GetSeverity() == SV_WARNING)) {
                 const auto annotationIter = annotations.lower_bound(bli->GetLineNumber());
-                if ((annotationIter == annotations.end()) || (annotationIter->first != bli->GetLineNumber()))
-                {
+                if((annotationIter == annotations.end()) || (annotationIter->first != bli->GetLineNumber())) {
                     // insert new one
                     AnnotationInfo info;
                     info.line = bli->GetLineNumber();
                     info.severity = bli->GetSeverity();
                     info.text.emplace(std::move(text));
                     annotations.emplace_hint(annotationIter, bli->GetLineNumber(), std::move(info));
-                }
-                else {
+                } else {
                     // we already have an error on this line, concatenate the message
                     AnnotationInfo& info = annotationIter->second;
                     info.text.emplace(std::move(text));
@@ -462,9 +466,8 @@ void NewBuildTab::MarkEditor(LEditor* editor)
     AnnotationInfoByLineMap_t::iterator annIter = annotations.begin();
     for(; annIter != annotations.end(); ++annIter) {
         wxString concatText;
-        for (auto &text : annIter->second.text) {
-            if (!concatText.IsEmpty())
-                concatText << "\n";
+        for(auto& text : annIter->second.text) {
+            if(!concatText.IsEmpty()) concatText << "\n";
             concatText << text;
         }
 
@@ -717,7 +720,7 @@ bool NewBuildTab::DoSelectAndOpen(int buildViewLine, bool centerLine)
                 fn = wxFileName(selection);
                 // if we resolved it now, open the file there is no point in searching this file
                 // in m_buildInfoPerFile since the key on this map is kept as full name
-                LEditor* editor = clMainFrame::Get()->GetMainBook()->FindEditor(fn.GetFullPath());
+                clEditor* editor = clMainFrame::Get()->GetMainBook()->FindEditor(fn.GetFullPath());
                 if(!editor) {
                     editor = clMainFrame::Get()->GetMainBook()->OpenFile(fn.GetFullPath(), wxT(""),
                                                                          bli->GetLineNumber(), wxNOT_FOUND, OF_AddJump);
@@ -733,7 +736,7 @@ bool NewBuildTab::DoSelectAndOpen(int buildViewLine, bool centerLine)
         if(fn.IsAbsolute()) {
 
             // try to locate the editor first
-            LEditor* editor = clMainFrame::Get()->GetMainBook()->FindEditor(fn.GetFullPath());
+            clEditor* editor = clMainFrame::Get()->GetMainBook()->FindEditor(fn.GetFullPath());
             if(!editor) {
                 // Open it
                 editor = clMainFrame::Get()->GetMainBook()->OpenFile(bli->GetFilename(), wxT(""), bli->GetLineNumber(),
@@ -760,7 +763,7 @@ wxFont NewBuildTab::DoGetFont() const
 {
     wxFont font = wxNullFont;
     LexerConf::Ptr_t lexerConf = EditorConfigST::Get()->GetLexer("C++");
-    if(lexerConf) { font = lexerConf->GetFontForSyle(wxSTC_C_DEFAULT); }
+    if(lexerConf) { font = lexerConf->GetFontForSyle(wxSTC_C_DEFAULT, this); }
 
     if(font.IsOk() == false) { font = wxSystemSettings::GetFont(wxSYS_ANSI_FIXED_FONT); }
 
@@ -784,7 +787,7 @@ void NewBuildTab::OnMenu(wxContextMenuEvent& e)
 void NewBuildTab::OnOpenInEditor(wxCommandEvent& e)
 {
     wxString content = this->GetBuildContent();
-    LEditor* editor = clMainFrame::Get()->GetMainBook()->NewEditor();
+    clEditor* editor = clMainFrame::Get()->GetMainBook()->NewEditor();
     if(editor) { editor->SetText(content); }
 }
 
@@ -864,15 +867,18 @@ void NewBuildTab::InitView(const wxString& theme)
 
     // reset the styles
     m_view->SetLexer(wxSTC_LEX_CONTAINER);
-    wxFont defaultFont = lexText->GetFontForSyle(0);
+    wxFont defaultFont = lexText->GetFontForSyle(0, this);
     for(size_t i = 0; i < wxSTC_STYLE_MAX; ++i) {
         m_view->StyleSetForeground(i, defaultStyle.GetFgColour());
         m_view->StyleSetBackground(i, defaultStyle.GetBgColour());
         m_view->StyleSetFont(i, defaultFont);
     }
 
-    m_view->StyleSetForeground(LEX_GCC_INFO, wxSystemSettings::GetColour(wxSYS_COLOUR_GRAYTEXT));
-    m_view->StyleSetForeground(LEX_GCC_DEFAULT, props[0].GetFgColour());
+    bool is_dark = DrawingUtils::IsDark(props[0].GetBgColour());
+    wxColour textColour = props[0].GetFgColour();
+    wxColour infoMsgColour = textColour.ChangeLightness(is_dark ? 50 : 150);
+    m_view->StyleSetForeground(LEX_GCC_INFO, infoMsgColour);
+    m_view->StyleSetForeground(LEX_GCC_DEFAULT, textColour);
     m_view->StyleSetForeground(LEX_GCC_WARNING, this->m_buildTabSettings.GetWarnColour());
     m_view->StyleSetForeground(LEX_GCC_ERROR, this->m_buildTabSettings.GetErrorColour());
 
@@ -910,7 +916,7 @@ void NewBuildTab::OnThemeChanged(wxCommandEvent& event)
     InitView();
 }
 
-void NewBuildTab::DoCentreErrorLine(BuildLineInfo* bli, LEditor* editor, bool centerLine)
+void NewBuildTab::DoCentreErrorLine(BuildLineInfo* bli, clEditor* editor, bool centerLine)
 {
     // We already got compiler markers set here, just goto the line
     clMainFrame::Get()->GetMainBook()->SelectPage(editor);
