@@ -18,6 +18,7 @@
 #include "memcheckdefs.h"
 #include "memcheckoutputview.h"
 #include "memchecksettings.h"
+#include "search_thread.h"
 
 MemCheckOutputView::MemCheckOutputView(wxWindow* parent, MemCheckPlugin* plugin, IManager* mgr)
     : MemCheckOutputViewBase(parent)
@@ -147,7 +148,6 @@ void MemCheckOutputView::ShowPageView(size_t page)
     m_currentPageIsEmptyView = true;
     m_currentItem = wxDataViewItem(0);
     m_onValueChangedLocked = false;
-    m_markedErrorsCount = 0;
     m_dataViewCtrlErrorsModel->Clear();
 
     if(m_totalErrorsView == 0) return;
@@ -174,11 +174,11 @@ void MemCheckOutputView::ShowPageView(size_t page)
     MemCheckIterTools::ErrorListIterator it = MemCheckIterTools::Factory(errorList, m_workspacePath, flags);
     for(; i < iStart && it != errorList.end(); ++i, ++it)
         ; // skipping item before start
-    // CL_DEBUG1(PLUGIN_PREFIX("items skiped"));
+    // CL_DEBUG1(PLUGIN_PREFIX("items skipped"));
     m_mgr->GetTheApp()->Yield();
     for(; i <= iStop; ++i, ++it) {
         if(it == errorList.end()) {
-            CL_WARNING(PLUGIN_PREFIX("Some items skiped. Total errors count mismatches the iterator."));
+            CL_WARNING(PLUGIN_PREFIX("Some items skipped. Total errors count mismatches the iterator."));
             break;
         }
         AddTree(wxDataViewItem(0), *it); // CL_DEBUG1(PLUGIN_PREFIX("adding %lu", i));
@@ -450,29 +450,6 @@ void MemCheckOutputView::MarkTree(const wxDataViewItem& item, bool checked)
     }
 }
 
-/**
- * @brief This callback is trigered when user click on checkbox - wants un/mark error.
- * @param event just wxDataViewEvent
- */
-void MemCheckOutputView::OnValueChanged(wxDataViewEvent& event)
-{
-    // CL_DEBUG1(PLUGIN_PREFIX("MemCheckOutputView::OnValueChanged()"));
-    int col = GetColumnByName(_("Suppress"));
-    if(col == wxNOT_FOUND) {
-        return;
-    }
-    if(m_onValueChangedLocked || event.GetColumn() != col) return;
-
-    m_onValueChangedLocked = true;
-
-    wxVariant variant;
-    m_dataViewCtrlErrorsModel->GetValue(variant, event.GetItem(), col);
-
-    MarkTree(GetTopParent(event.GetItem()), variant.GetBool());
-    variant.GetBool() ? ++m_markedErrorsCount : --m_markedErrorsCount;
-
-    m_onValueChangedLocked = false;
-}
 
 void MemCheckOutputView::OnContextMenu(wxDataViewEvent& event)
 {
@@ -480,6 +457,9 @@ void MemCheckOutputView::OnContextMenu(wxDataViewEvent& event)
 
     if(m_currentPageIsEmptyView) return;
 
+    bool unmarked, marked;
+    GetStatusOfErrors(unmarked, marked);
+
     const wxDataViewItem& dataItem = event.GetItem();
     wxMenuItem* menuItem(NULL);
     wxMenu menu;
@@ -487,23 +467,27 @@ void MemCheckOutputView::OnContextMenu(wxDataViewEvent& event)
     menuItem = menu.Append(XRCID("memcheck_jump_to_location"), wxT("Jump to location"));
     menuItem->Enable(dataItem.IsOk() && !m_dataViewCtrlErrorsModel->IsContainer(dataItem));
     menu.AppendSeparator();
+    menuItem = menu.Append(XRCID("memcheck_mark_all_errors"), "Mark all");
+    menuItem->Enable(unmarked);
     menuItem = menu.Append(XRCID("memcheck_unmark_all_errors"), wxT("Unmark all"));
-    menuItem->Enable(m_markedErrorsCount);
+    menuItem->Enable(marked);
     menu.AppendSeparator();
     menuItem = menu.Append(XRCID("memcheck_suppress_error"), wxT("Suppress this error"));
     menuItem->Enable(dataItem.IsOk() && m_choiceSuppFile->GetSelection() != wxNOT_FOUND);
     menuItem = menu.Append(XRCID("memcheck_suppress_marked_errors"), wxT("Suppress all marked errors"));
-    menuItem->Enable(m_markedErrorsCount && m_choiceSuppFile->GetSelection() != wxNOT_FOUND);
+    menuItem->Enable(marked && m_choiceSuppFile->GetSelection() != wxNOT_FOUND);
     menu.AppendSeparator();
     menuItem = menu.Append(XRCID("memcheck_row_to_clip"), wxT("Copy line as string to clipboard"));
     menuItem->Enable(dataItem.IsOk());
     menuItem = menu.Append(XRCID("memcheck_error_to_clip"), wxT("Copy error as string to clipboard"));
     menuItem->Enable(dataItem.IsOk());
     menuItem = menu.Append(XRCID("memcheck_marked_errors_to_clip"), wxT("Copy marked errors to clipboard"));
-    menuItem->Enable(m_markedErrorsCount);
+    menuItem->Enable(marked);
 
     menu.Connect(XRCID("memcheck_jump_to_location"), wxEVT_COMMAND_MENU_SELECTED,
         wxCommandEventHandler(MemCheckOutputView::OnJumpToLocation), new wxDataViewEvent(event), (wxEvtHandler*)this);
+    menu.Connect(XRCID("memcheck_mark_all_errors"), wxEVT_COMMAND_MENU_SELECTED,
+        wxCommandEventHandler(MemCheckOutputView::OnMarkAllErrors), new wxDataViewEvent(event), (wxEvtHandler*)this);
     menu.Connect(XRCID("memcheck_unmark_all_errors"), wxEVT_COMMAND_MENU_SELECTED,
         wxCommandEventHandler(MemCheckOutputView::OnUnmarkAllErrors), new wxDataViewEvent(event), (wxEvtHandler*)this);
     menu.Connect(XRCID("memcheck_suppress_error"), wxEVT_COMMAND_MENU_SELECTED,
@@ -532,13 +516,38 @@ void MemCheckOutputView::OnJumpToLocation(wxCommandEvent& event)
     JumpToLocation(item);
 }
 
+void MemCheckOutputView::OnMarkAllErrors(wxCommandEvent& event)
+{
+    MarkAllErrors(true);
+}
+
 void MemCheckOutputView::OnUnmarkAllErrors(wxCommandEvent& event)
+{
+    MarkAllErrors(false);
+}
+
+void MemCheckOutputView::MarkAllErrors(bool state)
 {
     wxDataViewItemArray items;
     m_dataViewCtrlErrorsModel->GetChildren(wxDataViewItem(0), items);
 
     for(wxDataViewItemArray::iterator it = items.begin(); it != items.end(); ++it) {
-        MarkTree(*it, false);
+        MarkTree(*it, state);
+    }
+}
+
+void MemCheckOutputView::GetStatusOfErrors(bool& unmarked, bool& marked)
+{
+    wxDataViewItemArray items;
+    wxVariant variant;
+    int supColumn = GetColumnByName(_("Suppress"));
+    if(supColumn == wxNOT_FOUND) {
+        return;
+    }
+    m_dataViewCtrlErrorsModel->GetChildren(wxDataViewItem(0), items);
+    for(wxDataViewItemArray::iterator it = items.begin(); it != items.end(); ++it) {
+        m_dataViewCtrlErrorsModel->GetValue(variant, *it, supColumn);
+        variant.GetBool() ? (marked = true):(unmarked = true);
     }
 }
 
@@ -970,3 +979,13 @@ void MemCheckOutputView::Clear()
 }
 void MemCheckOutputView::OnStop(wxCommandEvent& event) { m_plugin->StopProcess(); }
 void MemCheckOutputView::OnStopUI(wxUpdateUIEvent& event) { event.Enable(m_plugin->IsRunning()); }
+
+void MemCheckOutputView::OnClearOutput(wxCommandEvent& event)
+{
+    Clear();
+}
+
+void MemCheckOutputView::OnClearOutputUpdateUI(wxUpdateUIEvent& event)
+{
+    event.Enable(m_notebookOutputView->GetCurrentPage() == m_panelErrors && m_listCtrlErrors->GetItemCount() > 0);
+}
