@@ -16,15 +16,15 @@ PHPRefactoringOptions::PHPRefactoringOptions()
 
 PHPRefactoringOptions::~PHPRefactoringOptions() {}
 
-void PHPRefactoringOptions::FromJSON(const JSONElement& json)
+void PHPRefactoringOptions::FromJSON(const JSONItem& json)
 {
     m_phprefactoringPhar = json.namedObject("phprefactoringPhar").toString(m_phprefactoringPhar);
     m_skipPreview = json.namedObject("skipPreview").toBool(m_skipPreview);
 }
 
-JSONElement PHPRefactoringOptions::ToJSON() const
+JSONItem PHPRefactoringOptions::ToJSON() const
 {
-    JSONElement element = JSONElement::createObject(GetName());
+    JSONItem element = JSONItem::createObject(GetName());
     element.addProperty("phprefactoringPhar", m_phprefactoringPhar);
     element.addProperty("skipPreview", m_skipPreview);
     return element;
