@@ -72,23 +72,24 @@ static wxString GetMakeDirCmd(BuildConfigPtr bldConf, const wxString& relPath =
     return text;
 }
 
-BuilderGnuMake::BuilderGnuMake()
+BuilderGNUMakeClassic::BuilderGNUMakeClassic()
     : Builder("Default")
     , m_objectChunks(1)
     , m_projectFilesMetadata(nullptr)
 {
 }
 
-BuilderGnuMake::BuilderGnuMake(const wxString& name, const wxString& buildTool, const wxString& buildToolOptions)
+BuilderGNUMakeClassic::BuilderGNUMakeClassic(const wxString& name, const wxString& buildTool,
+                                             const wxString& buildToolOptions)
     : Builder(name)
     , m_projectFilesMetadata(nullptr)
 {
 }
 
-BuilderGnuMake::~BuilderGnuMake() {}
+BuilderGNUMakeClassic::~BuilderGNUMakeClassic() {}
 
-bool BuilderGnuMake::Export(const wxString& project, const wxString& confToBuild, const wxString& arguments,
-                            bool isProjectOnly, bool force, wxString& errMsg)
+bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& confToBuild, const wxString& arguments,
+                                   bool isProjectOnly, bool force, wxString& errMsg)
 {
     if(project.IsEmpty()) { return false; }
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
@@ -430,8 +431,8 @@ bool BuilderGnuMake::Export(const wxString& project, const wxString& confToBuild
     return true;
 }
 
-void BuilderGnuMake::GenerateMakefile(ProjectPtr proj, const wxString& confToBuild, bool force,
-                                      const wxArrayString& depsProj)
+void BuilderGNUMakeClassic::GenerateMakefile(ProjectPtr proj, const wxString& confToBuild, bool force,
+                                             const wxArrayString& depsProj)
 {
     wxString pname(proj->GetName());
     wxString tmpConfigName(confToBuild.c_str());
@@ -551,8 +552,8 @@ void BuilderGnuMake::GenerateMakefile(ProjectPtr proj, const wxString& confToBui
     proj->SetModified(false);
 }
 
-void BuilderGnuMake::CreateMakeDirsTarget(ProjectPtr proj, BuildConfigPtr bldConf, const wxString& targetName,
-                                          wxString& text)
+void BuilderGNUMakeClassic::CreateMakeDirsTarget(ProjectPtr proj, BuildConfigPtr bldConf, const wxString& targetName,
+                                                 wxString& text)
 {
     text << "\n";
     text << "MakeIntermediateDirs:\n";
@@ -563,7 +564,7 @@ void BuilderGnuMake::CreateMakeDirsTarget(ProjectPtr proj, BuildConfigPtr bldCon
     text << wxT("\t") << GetMakeDirCmd(bldConf) << wxT("\n");
 }
 
-void BuilderGnuMake::CreateSrcList(ProjectPtr proj, const wxString& confToBuild, wxString& text)
+void BuilderGNUMakeClassic::CreateSrcList(ProjectPtr proj, const wxString& confToBuild, wxString& text)
 {
     std::vector<wxFileName> files;
 
@@ -613,7 +614,7 @@ void BuilderGnuMake::CreateSrcList(ProjectPtr proj, const wxString& confToBuild,
     text << wxT("\n\n");
 }
 
-void BuilderGnuMake::CreateObjectList(ProjectPtr proj, const wxString& confToBuild, wxString& text)
+void BuilderGNUMakeClassic::CreateObjectList(ProjectPtr proj, const wxString& confToBuild, wxString& text)
 {
     m_objectChunks = 1;
     std::vector<wxFileName> files;
@@ -696,7 +697,7 @@ void BuilderGnuMake::CreateObjectList(ProjectPtr proj, const wxString& confToBui
     m_objectChunks = objCounter;
 }
 
-void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString& confToBuild, wxString& text)
+void BuilderGNUMakeClassic::CreateFileTargets(ProjectPtr proj, const wxString& confToBuild, wxString& text)
 {
     // get the project specific build configuration for the workspace active
     // configuration
@@ -789,9 +790,7 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString& confToBu
                 }
 
                 // set the file rule
-                text << objectName << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT(" ") << dependFile
-                     << wxT("\n");
-                text << wxT("\t") << compilationLine << wxT("\n");
+                text << objectName << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT("\n");
 
                 wxString cmpOptions(wxT("$(CXXFLAGS) $(IncludePCH)"));
                 if(isCFile) { cmpOptions = wxT("$(CFLAGS)"); }
@@ -802,11 +801,11 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString& confToBu
 
                 wxString compilerMacro = DoGetCompilerMacro(rel_paths.at(i).GetFullPath(wxPATH_UNIX));
                 if(generateDependenciesFiles) {
-                    text << dependFile << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT("\n");
                     text << wxT("\t") << wxT("@") << compilerMacro << wxT(" ") << cmpOptions
                          << wxT(" $(IncludePath) -MG -MP -MT") << objectName << wxT(" -MF") << dependFile
-                         << wxT(" -MM ") << source_file_to_compile << wxT("\n\n");
+                         << wxT(" -MM ") << source_file_to_compile << wxT("\n");
                 }
+                text << wxT("\t") << compilationLine << wxT("\n");
 
                 if(supportPreprocessOnlyFiles) {
                     text << preprocessedFile << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT("\n");
@@ -842,7 +841,7 @@ static wxString GetIntermediateFolder(BuildConfigPtr bldConf)
     return IntermediateDirectory;
 }
 
-void BuilderGnuMake::CreateCleanTargets(ProjectPtr proj, const wxString& confToBuild, wxString& text)
+void BuilderGNUMakeClassic::CreateCleanTargets(ProjectPtr proj, const wxString& confToBuild, wxString& text)
 {
     // get the project specific build configuration for the workspace active
     // configuration
@@ -910,7 +909,7 @@ void BuilderGnuMake::CreateCleanTargets(ProjectPtr proj, const wxString& confToB
     text << wxT("\n\n");
 }
 
-void BuilderGnuMake::CreateListMacros(ProjectPtr proj, const wxString& confToBuild, wxString& text)
+void BuilderGNUMakeClassic::CreateListMacros(ProjectPtr proj, const wxString& confToBuild, wxString& text)
 {
     // create a list of Sources
     // CreateSrcList(proj, confToBuild, text);  // Not used/needed for multi-step build
@@ -918,8 +917,9 @@ void BuilderGnuMake::CreateListMacros(ProjectPtr proj, const wxString& confToBui
     CreateObjectList(proj, confToBuild, text);
 }
 
-void BuilderGnuMake::CreateLinkTargets(const wxString& type, BuildConfigPtr bldConf, wxString& text,
-                                       wxString& targetName, const wxString& projName, const wxArrayString& depsProj)
+void BuilderGNUMakeClassic::CreateLinkTargets(const wxString& type, BuildConfigPtr bldConf, wxString& text,
+                                              wxString& targetName, const wxString& projName,
+                                              const wxArrayString& depsProj)
 {
     // incase project is type exe or dll, force link
     // this is to workaround bug in the generated makefiles
@@ -972,8 +972,8 @@ void BuilderGnuMake::CreateLinkTargets(const wxString& type, BuildConfigPtr bldC
     }
 }
 
-void BuilderGnuMake::CreateTargets(const wxString& type, BuildConfigPtr bldConf, wxString& text,
-                                   const wxString& projName)
+void BuilderGNUMakeClassic::CreateTargets(const wxString& type, BuildConfigPtr bldConf, wxString& text,
+                                          const wxString& projName)
 {
     bool markRebuilt(true);
     text << wxT("\t@$(MakeDirCommand) $(@D)\n");
@@ -990,37 +990,14 @@ void BuilderGnuMake::CreateTargets(const wxString& type, BuildConfigPtr bldConf,
         text << "\t@echo $(Objects" << i << ") " << oper << " $(ObjectsFileList)\n";
     }
 
-    if(type == PROJECT_TYPE_STATIC_LIBRARY) {
-        // create a static library
-        // In any case add the 'objects_file' target here
-        text << wxT("\t") << wxT("$(AR) $(ArchiveOutputSwitch)$(OutputFile)");
-        if(cmp && cmp->GetReadObjectFilesFromList()) {
-            text << wxT(" @$(ObjectsFileList) $(ArLibs)\n");
-        } else {
-            text << wxT(" $(Objects) $(ArLibs)\n");
-        }
+    // get the linker line. This call take into account the value
+    // for cmp->GetReadObjectFilesFromList
+    wxString linkerLine = cmp->GetLinkLine(type, cmp->GetReadObjectFilesFromList());
+    text << "\t" << linkerLine << "\n";
 
-    } else if(type == PROJECT_TYPE_DYNAMIC_LIBRARY) {
-        // create a shared library
-        text << wxT("\t") << wxT("$(SharedObjectLinkerName) $(OutputSwitch)$(OutputFile)");
-        if(cmp && cmp->GetReadObjectFilesFromList()) {
-            text << wxT(" @$(ObjectsFileList) ");
-        } else {
-            text << wxT(" $(Objects) ");
-        }
-        text << wxT("$(LibPath) $(Libs) $(LinkOptions)\n");
-
-    } else if(type == PROJECT_TYPE_EXECUTABLE) {
-        // create an executable
-        text << wxT("\t") << wxT("$(LinkerName) $(OutputSwitch)$(OutputFile)");
-        if(cmp && cmp->GetReadObjectFilesFromList()) {
-            text << wxT(" @$(ObjectsFileList) ");
-        } else {
-            text << wxT(" $(Objects) ");
-        }
-        text << wxT("$(LibPath) $(Libs) $(LinkOptions)\n");
-        markRebuilt = false;
-    }
+    // If the project type is library (shared or static)
+    // add a "rebuild" marker
+    markRebuilt = (type != PROJECT_TYPE_EXECUTABLE);
 
     // If a link occurred, mark this project as "rebuilt" so the parent project will
     // know that a re-link is required
@@ -1030,7 +1007,7 @@ void BuilderGnuMake::CreateTargets(const wxString& type, BuildConfigPtr bldConf,
     }
 }
 
-void BuilderGnuMake::CreatePostBuildEvents(ProjectPtr proj, BuildConfigPtr bldConf, wxString& text)
+void BuilderGNUMakeClassic::CreatePostBuildEvents(ProjectPtr proj, BuildConfigPtr bldConf, wxString& text)
 {
     if(!HasPostbuildCommands(bldConf)) return;
 
@@ -1066,7 +1043,7 @@ void BuilderGnuMake::CreatePostBuildEvents(ProjectPtr proj, BuildConfigPtr bldCo
     text << wxT("\t@echo Done\n");
 }
 
-bool BuilderGnuMake::HasPrebuildCommands(BuildConfigPtr bldConf) const
+bool BuilderGNUMakeClassic::HasPrebuildCommands(BuildConfigPtr bldConf) const
 {
     BuildCommandList cmds;
     bldConf->GetPreBuildCommands(cmds);
@@ -1078,7 +1055,7 @@ bool BuilderGnuMake::HasPrebuildCommands(BuildConfigPtr bldConf) const
     return false;
 }
 
-void BuilderGnuMake::CreatePreBuildEvents(ProjectPtr proj, BuildConfigPtr bldConf, wxString& text)
+void BuilderGNUMakeClassic::CreatePreBuildEvents(ProjectPtr proj, BuildConfigPtr bldConf, wxString& text)
 {
     BuildCommandList cmds;
     BuildCommandList::iterator iter;
@@ -1118,7 +1095,7 @@ void BuilderGnuMake::CreatePreBuildEvents(ProjectPtr proj, BuildConfigPtr bldCon
     }
 }
 
-void BuilderGnuMake::CreateConfigsVariables(ProjectPtr proj, BuildConfigPtr bldConf, wxString& text)
+void BuilderGNUMakeClassic::CreateConfigsVariables(ProjectPtr proj, BuildConfigPtr bldConf, wxString& text)
 {
     wxString name = bldConf->GetName();
     name = NormalizeConfigName(name);
@@ -1279,7 +1256,8 @@ void BuilderGnuMake::CreateConfigsVariables(ProjectPtr proj, BuildConfigPtr bldC
     text << wxT("\n\n");
 }
 
-wxString BuilderGnuMake::ParseIncludePath(const wxString& paths, const wxString& projectName, const wxString& selConf)
+wxString BuilderGNUMakeClassic::ParseIncludePath(const wxString& paths, const wxString& projectName,
+                                                 const wxString& selConf)
 {
     // convert semi-colon delimited string into GNU list of
     // include paths:
@@ -1294,7 +1272,8 @@ wxString BuilderGnuMake::ParseIncludePath(const wxString& paths, const wxString&
     return incluedPath;
 }
 
-wxString BuilderGnuMake::ParseLibPath(const wxString& paths, const wxString& projectName, const wxString& selConf)
+wxString BuilderGNUMakeClassic::ParseLibPath(const wxString& paths, const wxString& projectName,
+                                             const wxString& selConf)
 {
     // convert semi-colon delimited string into GNU list of
     // lib path
@@ -1310,7 +1289,7 @@ wxString BuilderGnuMake::ParseLibPath(const wxString& paths, const wxString& pro
     return libPath;
 }
 
-wxString BuilderGnuMake::ParsePreprocessor(const wxString& prep)
+wxString BuilderGNUMakeClassic::ParsePreprocessor(const wxString& prep)
 {
     wxString preprocessor(wxEmptyString);
     wxStringTokenizer tkz(prep, wxT(";"), wxTOKEN_STRTOK);
@@ -1328,7 +1307,7 @@ wxString BuilderGnuMake::ParsePreprocessor(const wxString& prep)
     return preprocessor;
 }
 
-wxString BuilderGnuMake::ParseLibs(const wxString& libs)
+wxString BuilderGNUMakeClassic::ParseLibs(const wxString& libs)
 {
     // convert semi-colon delimited string into GNU list of
     // libs
@@ -1353,8 +1332,8 @@ wxString BuilderGnuMake::ParseLibs(const wxString& libs)
     return slibs;
 }
 
-wxString BuilderGnuMake::GetBuildCommand(const wxString& project, const wxString& confToBuild,
-                                         const wxString& arguments)
+wxString BuilderGNUMakeClassic::GetBuildCommand(const wxString& project, const wxString& confToBuild,
+                                                const wxString& arguments)
 {
     wxString errMsg, cmd;
     BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetProjBuildConf(project, confToBuild);
@@ -1372,8 +1351,8 @@ wxString BuilderGnuMake::GetBuildCommand(const wxString& project, const wxString
     return cmd;
 }
 
-wxString BuilderGnuMake::GetCleanCommand(const wxString& project, const wxString& confToBuild,
-                                         const wxString& arguments)
+wxString BuilderGNUMakeClassic::GetCleanCommand(const wxString& project, const wxString& confToBuild,
+                                                const wxString& arguments)
 {
     wxString errMsg, cmd;
     BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetProjBuildConf(project, confToBuild);
@@ -1394,8 +1373,8 @@ wxString BuilderGnuMake::GetCleanCommand(const wxString& project, const wxString
     return cmd;
 }
 
-wxString BuilderGnuMake::GetPOBuildCommand(const wxString& project, const wxString& confToBuild,
-                                           const wxString& arguments)
+wxString BuilderGNUMakeClassic::GetPOBuildCommand(const wxString& project, const wxString& confToBuild,
+                                                  const wxString& arguments)
 {
     wxString errMsg, cmd;
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
@@ -1407,8 +1386,8 @@ wxString BuilderGnuMake::GetPOBuildCommand(const wxString& project, const wxStri
     return cmd;
 }
 
-wxString BuilderGnuMake::GetPOCleanCommand(const wxString& project, const wxString& confToBuild,
-                                           const wxString& arguments)
+wxString BuilderGNUMakeClassic::GetPOCleanCommand(const wxString& project, const wxString& confToBuild,
+                                                  const wxString& arguments)
 {
     wxString errMsg, cmd;
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
@@ -1420,8 +1399,8 @@ wxString BuilderGnuMake::GetPOCleanCommand(const wxString& project, const wxStri
     return cmd;
 }
 
-wxString BuilderGnuMake::GetSingleFileCmd(const wxString& project, const wxString& confToBuild,
-                                          const wxString& arguments, const wxString& fileName)
+wxString BuilderGNUMakeClassic::GetSingleFileCmd(const wxString& project, const wxString& confToBuild,
+                                                 const wxString& arguments, const wxString& fileName)
 {
     wxString errMsg, cmd;
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
@@ -1464,8 +1443,9 @@ wxString BuilderGnuMake::GetSingleFileCmd(const wxString& project, const wxStrin
     return EnvironmentConfig::Instance()->ExpandVariables(cmd, true);
 }
 
-wxString BuilderGnuMake::GetPreprocessFileCmd(const wxString& project, const wxString& confToBuild,
-                                              const wxString& arguments, const wxString& fileName, wxString& errMsg)
+wxString BuilderGNUMakeClassic::GetPreprocessFileCmd(const wxString& project, const wxString& confToBuild,
+                                                     const wxString& arguments, const wxString& fileName,
+                                                     wxString& errMsg)
 {
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
     if(!proj) { return wxEmptyString; }
@@ -1501,7 +1481,7 @@ wxString BuilderGnuMake::GetPreprocessFileCmd(const wxString& project, const wxS
     return EnvironmentConfig::Instance()->ExpandVariables(cmd, true);
 }
 
-wxString BuilderGnuMake::GetCdCmd(const wxFileName& path1, const wxFileName& path2)
+wxString BuilderGNUMakeClassic::GetCdCmd(const wxFileName& path1, const wxFileName& path2)
 {
     wxString cd_cmd(wxT("@"));
     if(path2.GetPath().IsEmpty()) { return cd_cmd; }
@@ -1510,7 +1490,7 @@ wxString BuilderGnuMake::GetCdCmd(const wxFileName& path1, const wxFileName& pat
     return cd_cmd;
 }
 
-void BuilderGnuMake::CreateCustomPostBuildEvents(BuildConfigPtr bldConf, wxString& text)
+void BuilderGNUMakeClassic::CreateCustomPostBuildEvents(BuildConfigPtr bldConf, wxString& text)
 {
     BuildCommandList cmds;
     BuildCommandList::iterator iter;
@@ -1533,7 +1513,7 @@ void BuilderGnuMake::CreateCustomPostBuildEvents(BuildConfigPtr bldConf, wxStrin
     }
 }
 
-void BuilderGnuMake::CreateCustomPreBuildEvents(BuildConfigPtr bldConf, wxString& text)
+void BuilderGNUMakeClassic::CreateCustomPreBuildEvents(BuildConfigPtr bldConf, wxString& text)
 {
     BuildCommandList cmds;
     BuildCommandList::iterator iter;
@@ -1556,8 +1536,8 @@ void BuilderGnuMake::CreateCustomPreBuildEvents(BuildConfigPtr bldConf, wxString
     }
 }
 
-wxString BuilderGnuMake::GetProjectMakeCommand(const wxFileName& wspfile, const wxFileName& projectPath,
-                                               ProjectPtr proj, const wxString& confToBuild)
+wxString BuilderGNUMakeClassic::GetProjectMakeCommand(const wxFileName& wspfile, const wxFileName& projectPath,
+                                                      ProjectPtr proj, const wxString& confToBuild)
 {
     BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetProjBuildConf(proj->GetName(), confToBuild);
 
@@ -1598,8 +1578,8 @@ wxString BuilderGnuMake::GetProjectMakeCommand(const wxFileName& wspfile, const
     return makeCommand;
 }
 
-wxString BuilderGnuMake::GetProjectMakeCommand(ProjectPtr proj, const wxString& confToBuild, const wxString& target,
-                                               size_t flags)
+wxString BuilderGNUMakeClassic::GetProjectMakeCommand(ProjectPtr proj, const wxString& confToBuild,
+                                                      const wxString& target, size_t flags)
 {
     bool bCleanOnly = flags & kCleanOnly;
     bool bIncludePreBuild = flags & kIncludePreBuild;
@@ -1647,7 +1627,7 @@ wxString BuilderGnuMake::GetProjectMakeCommand(ProjectPtr proj, const wxString&
     return makeCommand;
 }
 
-void BuilderGnuMake::CreatePreCompiledHeaderTarget(BuildConfigPtr bldConf, wxString& text)
+void BuilderGNUMakeClassic::CreatePreCompiledHeaderTarget(BuildConfigPtr bldConf, wxString& text)
 {
     wxString filename = bldConf->GetPrecompiledHeader();
     filename.Trim().Trim(false);
@@ -1668,8 +1648,8 @@ void BuilderGnuMake::CreatePreCompiledHeaderTarget(BuildConfigPtr bldConf, wxStr
     text << wxT("\n");
 }
 
-wxString BuilderGnuMake::GetPORebuildCommand(const wxString& project, const wxString& confToBuild,
-                                             const wxString& arguments)
+wxString BuilderGNUMakeClassic::GetPORebuildCommand(const wxString& project, const wxString& confToBuild,
+                                                    const wxString& arguments)
 {
     wxString errMsg, cmd;
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
@@ -1681,8 +1661,8 @@ wxString BuilderGnuMake::GetPORebuildCommand(const wxString& project, const wxSt
     return cmd;
 }
 
-wxString BuilderGnuMake::GetBuildToolCommand(const wxString& project, const wxString& confToBuild,
-                                             const wxString& arguments, bool isCommandlineCommand) const
+wxString BuilderGNUMakeClassic::GetBuildToolCommand(const wxString& project, const wxString& confToBuild,
+                                                    const wxString& arguments, bool isCommandlineCommand) const
 {
     wxString jobsCmd;
     wxString buildTool;
@@ -1715,7 +1695,7 @@ wxString BuilderGnuMake::GetBuildToolCommand(const wxString& project, const wxSt
     }
 }
 
-wxString BuilderGnuMake::DoGetCompilerMacro(const wxString& filename)
+wxString BuilderGNUMakeClassic::DoGetCompilerMacro(const wxString& filename)
 {
     wxString compilerMacro(wxT("$(CXX)"));
     switch(FileExtManager::GetType(filename)) {
@@ -1730,7 +1710,7 @@ wxString BuilderGnuMake::DoGetCompilerMacro(const wxString& filename)
     return compilerMacro;
 }
 
-wxString BuilderGnuMake::DoGetTargetPrefix(const wxFileName& filename, const wxString& cwd, CompilerPtr cmp)
+wxString BuilderGNUMakeClassic::DoGetTargetPrefix(const wxFileName& filename, const wxString& cwd, CompilerPtr cmp)
 {
     wxString lastDir;
     wxString ret;
@@ -1765,7 +1745,7 @@ wxString BuilderGnuMake::DoGetTargetPrefix(const wxFileName& filename, const wxS
     return ret;
 }
 
-wxString BuilderGnuMake::DoGetMarkerFileDir(const wxString& projname, const wxString& projectPath)
+wxString BuilderGNUMakeClassic::DoGetMarkerFileDir(const wxString& projname, const wxString& projectPath)
 {
     BuildMatrixPtr matrix = clCxxWorkspaceST::Get()->GetBuildMatrix();
     wxString workspaceSelConf = matrix->GetSelectedConfigurationName();
@@ -1794,7 +1774,7 @@ wxString BuilderGnuMake::DoGetMarkerFileDir(const wxString& projname, const wxSt
         return path;
 }
 
-bool BuilderGnuMake::HasPostbuildCommands(BuildConfigPtr bldConf) const
+bool BuilderGNUMakeClassic::HasPostbuildCommands(BuildConfigPtr bldConf) const
 {
     BuildCommandList cmds;
     bldConf->GetPostBuildCommands(cmds);
@@ -1806,7 +1786,7 @@ bool BuilderGnuMake::HasPostbuildCommands(BuildConfigPtr bldConf) const
     return false;
 }
 
-bool BuilderGnuMake::SendBuildEvent(int eventId, const wxString& projectName, const wxString& configurationName)
+bool BuilderGNUMakeClassic::SendBuildEvent(int eventId, const wxString& projectName, const wxString& configurationName)
 {
     clBuildEvent e(eventId);
     e.SetProjectName(projectName);
