@@ -5,8 +5,16 @@
 #include "codelite_exports.h"
 #include <wx/frame.h>
 
-class WXDLLIMPEXP_SDK clDiffFrame : public wxDialog
+class WXDLLIMPEXP_SDK clDiffFrame : public wxFrame
 {
+protected:
+    DiffSideBySidePanel* m_diffView = nullptr;
+
+protected:
+    void CreateMenuBar();
+    void OnClose(wxCommandEvent& event);
+    void OnCharHook(wxKeyEvent& event);
+
 public:
     clDiffFrame(wxWindow* parent, const DiffSideBySidePanel::FileInfo& left, const DiffSideBySidePanel::FileInfo& right,
                 bool originSourceControl);
