@@ -11,15 +11,10 @@ class WXDLLIMPEXP_SDK clEditorBar : public clEditorBarBase
 {
     wxString m_classname;
     wxString m_function;
-    wxColour m_functionColour;
-    wxColour m_classColour;
-    wxColour m_defaultColour;
-    wxColour m_bgColour;
     wxFont m_textFont;
     wxRect m_scopeRect;
-    eButtonState m_scopeButtonState;
     wxBitmap m_functionBmp;
-    
+
     // Breadcrumbs
     wxString m_filename;
     wxString m_filenameRelative;
@@ -28,14 +23,14 @@ class WXDLLIMPEXP_SDK clEditorBar : public clEditorBarBase
     wxArrayString m_breadcrumbs;
 
     wxRect m_filenameRect;
-    eButtonState m_state;
 
     // Bookmarks button
     wxBitmap m_bookmarksBmp;
     wxRect m_bookmarksRect;
-    eButtonState m_bookmarksButtonState;
     std::vector<std::pair<int, wxString> > m_bookmarks;
 
+    bool m_shouldShow = false;
+
 private:
     void DoRefreshColoursAndFonts();
     void DoRefresh();
@@ -48,14 +43,11 @@ public:
     void DoShow(bool s);
 
 protected:
+    virtual void OnButtonActions(wxCommandEvent& event);
+    virtual void OnButtonBookmarks(wxCommandEvent& event);
+    virtual void OnButtonScope(wxCommandEvent& event);
     void OnMarkerChanged(clCommandEvent& event);
-    void OnEditorSize(wxSizeEvent& e);
-    void OnEraseBG(wxEraseEvent& e);
-    void OnPaint(wxPaintEvent& e);
     void OnEditorChanged(wxCommandEvent& e);
-    void OnLeftDown(wxMouseEvent& e);
-    void OnLeftUp(wxMouseEvent& e);
     void OnThemeChanged(wxCommandEvent& e);
-    void OnIdle(wxIdleEvent& event);
 };
 #endif // CLEDITORBAR_H
