@@ -48,17 +48,51 @@ static void GetWhitespaceInfo(wxStyledTextCtrl* ctrl, wxString& whitespace, wxSt
 
 class WXDLLIMPEXP_SDK clStatusBarArtNormal : public wxCustomStatusBarArt
 {
+    wxColour m_bgColour;
+    wxColour m_penColour;
+    wxColour m_textColour;
+    wxColour m_separatorColour;
+
+protected:
+    void InitialiseColours()
+    {
+        m_bgColour = clSystemSettings::GetColour(wxSYS_COLOUR_3DFACE);
+        bool isdark = DrawingUtils::IsDark(m_bgColour);
+        m_bgColour = m_bgColour.ChangeLightness(isdark ? 105 : 95);
+
+        m_penColour = m_bgColour; // clSystemSettings::GetColour(wxSYS_COLOUR_3DSHADOW);
+        m_textColour = clSystemSettings::GetColour(wxSYS_COLOUR_BTNTEXT);
+        m_separatorColour = m_bgColour; // clSystemSettings::GetColour(wxSYS_COLOUR_3DSHADOW);
+    }
+
+    void OnColoursChanged(clCommandEvent& event)
+    {
+        event.Skip();
+        InitialiseColours();
+    }
+
 public:
     clStatusBarArtNormal()
         : wxCustomStatusBarArt("Light")
     {
-        m_textColour = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT);
-        m_textShadowColour = DrawingUtils::GetPanelBgColour();
-        m_penColour = wxSystemSettings::GetColour(wxSYS_COLOUR_3DSHADOW);
-        m_bgColour = DrawingUtils::GetPanelBgColour();
-        m_separatorColour = *wxWHITE;
+        InitialiseColours();
+        EventNotifier::Get()->Bind(wxEVT_SYS_COLOURS_CHANGED, &clStatusBarArtNormal::OnColoursChanged, this);
     }
-    virtual ~clStatusBarArtNormal() {}
+    virtual ~clStatusBarArtNormal()
+    {
+        EventNotifier::Get()->Unbind(wxEVT_SYS_COLOURS_CHANGED, &clStatusBarArtNormal::OnColoursChanged, this);
+    }
+
+    void DrawFieldSeparator(wxDC& dc, const wxRect& fieldRec)
+    {
+        wxUnusedVar(dc);
+        wxUnusedVar(fieldRec);
+    }
+
+    virtual wxColour GetBgColour() const { return m_bgColour; }
+    virtual wxColour GetPenColour() const { return m_penColour; }
+    virtual wxColour GetTextColour() const { return m_textColour; }
+    virtual wxColour GetSeparatorColour() const { return m_separatorColour; }
 };
 
 clStatusBar::clStatusBar(wxWindow* parent, IManager* mgr)
@@ -83,7 +117,8 @@ clStatusBar::clStatusBar(wxWindow* parent, IManager* mgr)
     wxCustomStatusBarField::Ptr_t sourceControl(new wxCustomStatusBarBitmapField(this, clGetScaledSize(30)));
     AddField(sourceControl);
 
-    wxCustomStatusBarField::Ptr_t lineCol(new wxCustomStatusBarFieldText(this, clGetScaledSize(300)));
+    int lineColWidth = GetTextWidth("Ln 100000, Col 999, Pos 12345678, Len 4821182");
+    wxCustomStatusBarField::Ptr_t lineCol(new wxCustomStatusBarFieldText(this, lineColWidth));
     AddField(lineCol);
 
     wxCustomStatusBarField::Ptr_t buildAnimation(new wxCustomStatusBarAnimationField(
@@ -96,7 +131,9 @@ clStatusBar::clStatusBar(wxWindow* parent, IManager* mgr)
     wxCustomStatusBarField::Ptr_t eol(new wxCustomStatusBarFieldText(this, clGetScaledSize(50)));
     AddField(eol);
 
-    wxCustomStatusBarField::Ptr_t language(new wxCustomStatusBarFieldText(this, clGetScaledSize(100)));
+    // The longest language that we have is "properties"
+    int languageWidth = GetTextWidth("_properties_");
+    wxCustomStatusBarField::Ptr_t language(new wxCustomStatusBarFieldText(this, languageWidth));
     AddField(language);
 
     wxCustomStatusBarField::Ptr_t encoding(new wxCustomStatusBarFieldText(this, clGetScaledSize(80)));
@@ -147,15 +184,15 @@ void clStatusBar::DoUpdateColour()
         wxColour bgColour = editor->GetCtrl()->StyleGetBackground(0);
         if(DrawingUtils::IsDark(bgColour)) {
             // Using dark theme background
-            art.reset(new wxCustomStatusBarArt("Dark"));
+            art.reset(new clStatusBarArtNormal());
             SetArt(art);
         } else {
-            art.reset(new wxCustomStatusBarArt("Dark"));
+            art.reset(new clStatusBarArtNormal());
             SetArt(art);
         }
     } else {
         // Non editor, set "normal" art
-        art.reset(new wxCustomStatusBarArt("Dark"));
+        art.reset(new clStatusBarArtNormal());
         SetArt(art);
     }
     Refresh();
@@ -581,3 +618,16 @@ void clStatusBar::OnActionSelected(clGotoEvent& e)
         ColoursAndFontsManager::Get().Save();
     }
 }
+
+int clStatusBar::GetTextWidth(const wxString& text) const
+{
+    const int SPACER = 10;
+    wxBitmap bmp(1, 1);
+    wxMemoryDC memDc;
+    memDc.SelectObject(bmp);
+    wxGCDC gcdc(memDc);
+    gcdc.SetFont(DrawingUtils::GetDefaultGuiFont());
+    int textWidth = gcdc.GetTextExtent(text).GetWidth();
+    textWidth += 2 * SPACER;
+    return textWidth;
+}
