@@ -4,6 +4,7 @@
 
 #include "ColoursAndFontsManager.h"
 #include "Notebook.h"
+#include "clSystemSettings.h"
 #include "clTabRenderer.h"
 #include "clTabRendererClassic.h"
 #include "clTabRendererCurved.h"
@@ -11,17 +12,17 @@
 #include "clTabRendererSquare.h"
 #include "cl_config.h"
 #include "editor_config.h"
+#include "wxStringHash.h"
 #include <wx/dcmemory.h>
 #include <wx/renderer.h>
 #include <wx/settings.h>
 #include <wx/xrc/xmlres.h>
-#include "clSystemSettings.h"
 
 #if CL_BUILD
 #include "drawingutils.h"
 #endif
 
-#define X_BUTTON_SIZE 14
+static int X_BUTTON_SIZE = 14;
 
 clTabColours::clTabColours() { InitDarkColours(); }
 
@@ -102,6 +103,22 @@ void clTabColours::InitLightColours()
 
 bool clTabColours::IsDarkColours() const { return DrawingUtils::IsDark(activeTabBgColour); }
 
+static void SetBestXButtonSize(wxWindow* win)
+{
+    wxUnusedVar(win);
+    static bool once = true;
+
+    if(once) {
+        once = false;
+        wxBitmap bmp(1, 1);
+        wxMemoryDC dc(bmp);
+        wxGCDC gcdc(dc);
+        gcdc.SetFont(DrawingUtils::GetDefaultGuiFont());
+        wxSize sz = gcdc.GetTextExtent("T");
+        X_BUTTON_SIZE = wxMax(sz.x, sz.y);
+    }
+}
+
 clTabInfo::clTabInfo(clTabCtrl* tabCtrl, size_t style, wxWindow* page, const wxString& text, const wxBitmap& bmp)
     : m_bitmap(bmp)
     , m_tabCtrl(tabCtrl)
@@ -109,7 +126,9 @@ clTabInfo::clTabInfo(clTabCtrl* tabCtrl, size_t style, wxWindow* page, const wxS
     , m_window(page)
     , m_active(false)
     , m_textWidth(0)
+    , m_xButtonState(eButtonState::kDisabled)
 {
+    SetBestXButtonSize(tabCtrl);
     CalculateOffsets(style);
     if(m_bitmap.IsOk()) { m_disabledBitmp = DrawingUtils::CreateDisabledBitmap(m_bitmap); }
 }
@@ -125,7 +144,9 @@ clTabInfo::clTabInfo(clTabCtrl* tabCtrl)
     , m_bmpCloseX(wxNOT_FOUND)
     , m_bmpCloseY(wxNOT_FOUND)
     , m_textWidth(0)
+    , m_xButtonState(eButtonState::kDisabled)
 {
+    SetBestXButtonSize(tabCtrl);
     CalculateOffsets(0);
 }
 
@@ -139,10 +160,12 @@ void clTabInfo::CalculateOffsets(size_t style, wxDC& dc)
     int M_spacer = m_tabCtrl ? m_tabCtrl->GetArt()->majorCurveWidth : 5;
     int S_spacer = m_tabCtrl ? m_tabCtrl->GetArt()->smallCurveWidth : 2;
 
-    wxFont font = clTabRenderer::GetTabFont(true);
+    wxFont font = clTabRenderer::GetTabFont(false);
     dc.SetFont(font);
 
-    wxSize sz = dc.GetTextExtent(m_label);
+    bool bVerticalTabs = IS_VERTICAL_TABS(style);
+    // On vertical tabs, use the short label
+    wxSize sz = dc.GetTextExtent(GetBestLabel(style));
     wxSize fixedHeight = dc.GetTextExtent("Tp");
     m_height = fixedHeight.GetHeight() + (4 * Y_spacer);
 
@@ -155,16 +178,15 @@ void clTabInfo::CalculateOffsets(size_t style, wxDC& dc)
     m_width += M_spacer;
     m_width += S_spacer;
 
-    bool bVerticalTabs = IS_VERTICAL_TABS(style);
     // bitmap
     m_bmpX = wxNOT_FOUND;
     m_bmpY = wxNOT_FOUND;
 
     if(m_bitmap.IsOk() && !bVerticalTabs) {
         m_bmpX = m_width;
-        m_width += X_spacer;
         m_width += m_bitmap.GetScaledWidth();
         m_bmpY = ((m_height - m_bitmap.GetScaledHeight()) / 2);
+        m_width += X_spacer;
     }
 
     // Text
@@ -172,20 +194,22 @@ void clTabInfo::CalculateOffsets(size_t style, wxDC& dc)
     m_textY = ((m_height - sz.y) / 2);
     m_width += sz.x;
     m_textWidth = sz.x;
+    m_width += X_spacer;
 
     // x button
     wxRect xrect;
     if((style & kNotebook_CloseButtonOnActiveTab)) {
-        m_width += X_spacer;
         xrect = wxRect(m_width, 0, X_BUTTON_SIZE, X_BUTTON_SIZE);
         m_bmpCloseX = xrect.GetX();
         m_bmpCloseY = 0; // we will fix this later
         m_width += xrect.GetWidth();
+        m_width += X_spacer;
     }
 
-    m_width += X_spacer;
+    // Extra spacers
     m_width += M_spacer;
     m_width += S_spacer;
+
     if((style & kNotebook_UnderlineActiveTab) && bVerticalTabs) { m_width += 8; }
     // Update the rect width
     m_rect.SetWidth(m_width);
@@ -222,32 +246,45 @@ void clTabInfo::SetLabel(const wxString& label, size_t style)
 void clTabInfo::SetActive(bool active, size_t style)
 {
     this->m_active = active;
+    this->m_xButtonState = active ? eButtonState::kNormal : eButtonState::kDisabled;
     CalculateOffsets(style);
 }
 
 wxRect clTabInfo::GetCloseButtonRect() const
 {
-    wxRect xRect(GetRect().x + GetBmpCloseX(), GetRect().y + GetBmpCloseY(), clTabRenderer::GetXButtonSize(),
-                 clTabRenderer::GetXButtonSize());
-    return xRect;
+    wxRect xRect(GetBmpCloseX() + GetRect().x, 0, clTabRenderer::GetXButtonSize(), clTabRenderer::GetXButtonSize());
+    xRect.Inflate(2);
+    return xRect.CenterIn(GetRect(), wxVERTICAL);
 }
 
-clTabRenderer::clTabRenderer(const wxString& name)
+const wxString& clTabInfo::GetBestLabel(size_t style) const
+{
+    if((style & (kNotebook_RightTabs | kNotebook_LeftTabs)) && !m_shortLabel.empty()) {
+        return m_shortLabel;
+    } else {
+        return m_label;
+    }
+}
+
+std::unordered_map<wxString, clTabRenderer*> clTabRenderer::ms_Renderes;
+
+clTabRenderer::clTabRenderer(const wxString& name, const wxWindow* parent)
     : bottomAreaHeight(0)
     , majorCurveWidth(0)
     , smallCurveWidth(0)
     , overlapWidth(0)
     , verticalOverlapWidth(0)
-    , xSpacer(10)
+    , ySpacer(5)
     , m_name(name)
 {
-    ySpacer = EditorConfigST::Get()->GetOptions()->GetNotebookTabHeight();
+    xSpacer = ::clGetSize(10, parent);
+    ySpacer = EditorConfigST::Get()->GetOptions()->GetNotebookTabHeight() + 2;
 }
 
 wxFont clTabRenderer::GetTabFont(bool bold)
 {
+    wxUnusedVar(bold);
     wxFont f = DrawingUtils::GetDefaultGuiFont();
-    if(bold) { f.SetWeight(wxFONTWEIGHT_BOLD); }
     return f;
 }
 
@@ -338,27 +375,23 @@ int clTabRenderer::GetDefaultBitmapHeight(int Y_spacer)
     return bmpHeight;
 }
 
-clTabRenderer::Ptr_t clTabRenderer::CreateRenderer(size_t tabStyle)
+clTabRenderer::Ptr_t clTabRenderer::CreateRenderer(const wxWindow* win, size_t tabStyle)
 {
-    wxString tab = clConfig::Get().Read("TabStyle", wxString("GTK3"));
+    if(ms_Renderes.empty()) {
+        RegisterRenderer(new clTabRendererSquare(win));
+        RegisterRenderer(new clTabRendererGTK3(win));
+        RegisterRenderer(new clTabRendererClassic(win));
+        RegisterRenderer(new clTabRendererCurved(win));
+    }
+
+    wxString tab = clConfig::Get().Read("TabStyle", wxString("MINIMAL"));
     wxString name = tab.Upper();
     if((tabStyle & kNotebook_LeftTabs) || (tabStyle & kNotebook_RightTabs)) {
-        // Only these styles support vertical tabs
-        if(name == "MINIMAL") {
-            return clTabRenderer::Ptr_t(new clTabRendererSquare());
-        } else {
-            return clTabRenderer::Ptr_t(new clTabRendererGTK3());
-        }
-    }
-    if(name == "MINIMAL") {
-        return clTabRenderer::Ptr_t(new clTabRendererSquare());
-    } else if(name == "TRAPEZOID") {
-        return clTabRenderer::Ptr_t(new clTabRendererCurved());
-    } else if(name == "GTK3") {
-        return clTabRenderer::Ptr_t(new clTabRendererGTK3());
-    } else {
-        return clTabRenderer::Ptr_t(new clTabRendererClassic());
+        return clTabRenderer::Ptr_t(Create(win, "MINIMAL"));
     }
+    clTabRenderer* r = Create(win, name);
+    if(!r) { r = Create(win, "DEFAULT"); }
+    return clTabRenderer::Ptr_t(r);
 }
 
 wxArrayString clTabRenderer::GetRenderers()
@@ -429,6 +462,8 @@ void clTabRenderer::DrawMarker(wxDC& dc, const clTabInfo& tabInfo, const clTabCo
     wxPen markerPen(colours.markerColour);
     // Draw marker line if needed
     // wxRect confinedRect = parent->GetClientRect();
+    bool isGTK3 = (GetName() == "GTK3");
+    wxDirection direction;
     wxPoint p1, p2;
     if((style & kNotebook_LeftTabs)) {
         p1 = tabInfo.GetRect().GetTopRight();
@@ -443,16 +478,31 @@ void clTabRenderer::DrawMarker(wxDC& dc, const clTabInfo& tabInfo, const clTabCo
         DrawMarkerLine(dc, p1, p2, wxRIGHT);
     } else if(style & kNotebook_BottomTabs) {
         // Bottom tabs
-        p1 = tabInfo.GetRect().GetTopLeft();
-        p2 = tabInfo.GetRect().GetTopRight();
+        if(isGTK3) {
+            direction = wxDOWN;
+            p1 = tabInfo.GetRect().GetTopLeft();
+            p2 = tabInfo.GetRect().GetTopRight();
+        } else {
+            direction = wxUP;
+            p1 = tabInfo.GetRect().GetBottomLeft();
+            p2 = tabInfo.GetRect().GetBottomRight();
+        }
         dc.SetPen(markerPen);
-        DrawMarkerLine(dc, p1, p2, wxDOWN);
+        DrawMarkerLine(dc, p1, p2, direction);
     } else {
         // Top tabs
-        p1 = tabInfo.GetRect().GetBottomLeft();
-        p2 = tabInfo.GetRect().GetBottomRight();
+        if(isGTK3) {
+            direction = wxUP;
+            p1 = tabInfo.GetRect().GetBottomLeft();
+            p2 = tabInfo.GetRect().GetBottomRight();
+
+        } else {
+            direction = wxDOWN;
+            p1 = tabInfo.GetRect().GetTopLeft();
+            p2 = tabInfo.GetRect().GetTopRight();
+        }
         dc.SetPen(markerPen);
-        DrawMarkerLine(dc, p1, p2, wxUP);
+        DrawMarkerLine(dc, p1, p2, direction);
     }
 }
 
@@ -481,3 +531,16 @@ void clTabRenderer::DrawMarkerLine(wxDC& dc, const wxPoint& p1, const wxPoint& p
 }
 
 int clTabRenderer::GetXButtonSize() { return X_BUTTON_SIZE; }
+
+void clTabRenderer::RegisterRenderer(clTabRenderer* renderer)
+{
+    if(!renderer) { return; }
+    if(ms_Renderes.count(renderer->GetName())) { return; }
+    ms_Renderes.insert({ renderer->GetName(), renderer });
+}
+
+clTabRenderer* clTabRenderer::Create(const wxWindow* parent, const wxString& name)
+{
+    if(ms_Renderes.count(name) == 0) { return nullptr; }
+    return ms_Renderes.find(name)->second->New(parent);
+}
