@@ -299,7 +299,7 @@ bool CustomBuildRequest::DoUpdateCommand(IManager* manager, wxString& cmd, Proje
     cmd << wxT("\"") << fn << wxT("\"");
 #else
     // *nix
-    cmd << wxT("/bin/sh './") << fn << wxT("'");
+    cmd << wxT("/bin/bash './") << fn << wxT("'");
 #endif
     return true;
 }
