@@ -23,6 +23,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "bookmark_manager.h"
+#include "cl_config.h"
 #include "drawingutils.h"
 #include "editor_config.h"
 #include "globals.h"
@@ -32,20 +33,26 @@
 #include "xmlutils.h"
 #include <algorithm>
 #include <wx/settings.h>
+#include <wx/stc/stc.h>
 #include <wx/utils.h>
-#include "cl_config.h"
 
 #ifdef __WXMSW__
 #define DEFAULT_FACE_NAME "Consolas"
-#define DEFAULT_FONT_SIZE 10
+#define DEFAULT_FONT_SIZE 12
 #elif defined(__WXMAC__)
 #define DEFAULT_FACE_NAME "monaco"
 #define DEFAULT_FONT_SIZE 14
 #else // GTK, FreeBSD etc
-#define DEFAULT_FACE_NAME "monospace"
+#define DEFAULT_FACE_NAME "Monospace"
 #define DEFAULT_FONT_SIZE 12
 #endif
 
+#ifdef __WXGTK__
+#define FIX_FONT_SIZE(size, ctrl) clGetSize(size, ctrl)
+#else
+#define FIX_FONT_SIZE(size, ctrl) size
+#endif
+
 static bool StringTolBool(const wxString& s)
 {
     bool res = s.CmpNoCase(wxT("Yes")) == 0 ? true : false;
@@ -225,7 +232,7 @@ wxXmlNode* LexerConf::ToXml() const
     return node;
 }
 
-wxFont LexerConf::GetFontForSyle(int styleId) const
+wxFont LexerConf::GetFontForSyle(int styleId, const wxWindow* win) const
 {
     StyleProperty::Map_t::const_iterator iter = m_properties.find(styleId);
     if(iter != m_properties.end()) {
@@ -238,8 +245,8 @@ wxFont LexerConf::GetFontForSyle(int styleId) const
             face = DEFAULT_FACE_NAME;
         }
 
-        wxFontInfo fontInfo = wxFontInfo(fontSize)
-                                  .Family(wxFONTFAMILY_TELETYPE)
+        wxFontInfo fontInfo = wxFontInfo(FIX_FONT_SIZE(fontSize, win))
+                                  .Family(wxFONTFAMILY_MODERN)
                                   .Italic(prop.GetItalic())
                                   .Bold(prop.IsBold())
                                   .Underlined(prop.GetUnderlined())
@@ -265,6 +272,10 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
 {
     ctrl->SetLexer(GetLexerId());
     ctrl->StyleClearAll();
+#if wxCHECK_VERSION(3, 1, 0)
+    ctrl->FoldDisplayTextSetStyle(wxSTC_FOLDDISPLAYTEXT_BOXED);
+    ctrl->SetIdleStyling(wxSTC_IDLESTYLING_TOVISIBLE);
+#endif
 
 #ifndef __WXMSW__
     ctrl->SetStyleBits(ctrl->GetStyleBitsNeeded());
@@ -273,14 +284,7 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
 #if defined(__WXMSW__)
     bool useDirect2D = clConfig::Get().Read("Editor/UseDirect2D", true);
     ctrl->SetTechnology(useDirect2D ? wxSTC_TECHNOLOGY_DIRECTWRITE : wxSTC_TECHNOLOGY_DEFAULT);
-#elif defined(__WXGTK__)
-    // ctrl->SetTechnology(wxSTC_TECHNOLOGY_DIRECTWRITE);
-    // ctrl->SetDoubleBuffered(false);
-#if wxCHECK_VERSION(3, 1, 1)
-    // ctrl->SetFontQuality(wxSTC_EFF_QUALITY_ANTIALIASED);
 #endif
-#endif
-
     OptionsConfigPtr options = EditorConfigST::Get()->GetOptions();
     bool tooltip(false);
 
@@ -299,7 +303,7 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
     // Find the default style
     wxFont defaultFont;
     bool foundDefaultStyle = false;
-    int nDefaultFontSize = DEFAULT_FONT_SIZE;
+    int nDefaultFontSize = FIX_FONT_SIZE(DEFAULT_FONT_SIZE, ctrl);
 
     StyleProperty defaultStyle;
     StyleProperty::Map_t::const_iterator iter = styles.begin();
@@ -309,32 +313,28 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
             defaultStyle = prop;
             wxString fontFace = prop.GetFaceName().IsEmpty() ? DEFAULT_FACE_NAME : prop.GetFaceName();
             if(!prop.GetFaceName().IsEmpty()) { nDefaultFontSize = prop.GetFontSize(); }
-            defaultFont = wxFont(
-                nDefaultFontSize, wxFONTFAMILY_TELETYPE, prop.GetItalic() ? wxFONTSTYLE_ITALIC : wxFONTSTYLE_NORMAL,
-                prop.IsBold() ? wxFONTWEIGHT_BOLD : wxFONTWEIGHT_NORMAL, prop.GetUnderlined(), fontFace);
+            wxFont defaultFont(
+                wxFontInfo(FIX_FONT_SIZE(nDefaultFontSize, ctrl)).Family(wxFONTFAMILY_MODERN).FaceName(fontFace));
+            if(prop.IsBold()) { defaultFont.SetWeight(wxFONTWEIGHT_BOLD); }
+            if(prop.GetUnderlined()) { defaultFont.SetStyle(wxFONTSTYLE_ITALIC); }
             foundDefaultStyle = true;
             break;
         }
     }
 
     // Reset all colours to use the default style colour
+    bool defaultFontOK = defaultFont.IsOk();
     if(foundDefaultStyle) {
-        for(int i = 0; i < 256; i++) {
+        for(int i = 0; i < wxSTC_STYLE_MAX; ++i) {
             ctrl->StyleSetBackground(i, defaultStyle.GetBgColour());
             ctrl->StyleSetForeground(i, defaultStyle.GetFgColour());
+            if(defaultFontOK) { ctrl->StyleSetFont(i, defaultFont); }
         }
     }
 
-    if(foundDefaultStyle && defaultFont.IsOk()) {
-        for(int i = 0; i < 256; i++) {
-            ctrl->StyleSetFont(i, defaultFont);
-        }
-    }
+    for(const auto& vt : styles) {
+        const StyleProperty& sp = vt.second;
 
-    iter = styles.begin();
-    for(; iter != styles.end(); ++iter) {
-
-        StyleProperty sp = iter->second;
         int size = nDefaultFontSize;
         wxString face = sp.GetFaceName();
         bool bold = sp.IsBold();
@@ -382,9 +382,9 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
                 fontSize = nDefaultFontSize;
                 faceName = DEFAULT_FACE_NAME;
             }
-
+            fontSize = FIX_FONT_SIZE(size, ctrl);
             wxFontInfo fontInfo = wxFontInfo(fontSize)
-                                      .Family(wxFONTFAMILY_TELETYPE)
+                                      .Family(wxFONTFAMILY_MODERN)
                                       .Italic(italic)
                                       .Bold(bold)
                                       .Underlined(underline)
@@ -393,7 +393,7 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
 
             if(sp.GetId() == 0) { // default
                 ctrl->StyleSetFont(wxSTC_STYLE_DEFAULT, font);
-                ctrl->StyleSetSize(wxSTC_STYLE_DEFAULT, size);
+                // ctrl->StyleSetSize(wxSTC_STYLE_DEFAULT, size);
                 ctrl->StyleSetForeground(wxSTC_STYLE_DEFAULT, iter->second.GetFgColour());
 
                 // Set the inactive state colours
@@ -401,11 +401,12 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
                 wxColor inactiveColor = GetInactiveColor(defaultStyle);
                 ctrl->StyleSetForeground(wxSTC_STYLE_DEFAULT + 64, inactiveColor);
                 ctrl->StyleSetFont(wxSTC_STYLE_DEFAULT + 64, font);
-                ctrl->StyleSetSize(wxSTC_STYLE_DEFAULT + 64, size);
+
                 ctrl->StyleSetBackground(wxSTC_STYLE_DEFAULT + 64, iter->second.GetBgColour());
 
                 ctrl->StyleSetBackground(wxSTC_STYLE_DEFAULT, iter->second.GetBgColour());
-                ctrl->StyleSetSize(wxSTC_STYLE_LINENUMBER, size);
+                ctrl->StyleSetFont(wxSTC_STYLE_LINENUMBER + 64, font);
+                // ctrl->StyleSetSize(wxSTC_STYLE_LINENUMBER, size);
 
             } else if(sp.GetId() == wxSTC_STYLE_CALLTIP) {
                 tooltip = true;
@@ -416,7 +417,7 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
             }
 
             ctrl->StyleSetFont(sp.GetId(), font);
-            ctrl->StyleSetSize(sp.GetId(), fontSize);
+            // ctrl->StyleSetSize(sp.GetId(), fontSize);
             ctrl->StyleSetEOLFilled(sp.GetId(), iter->second.GetEolFilled());
 
             if(iter->second.GetId() == LINE_NUMBERS_ATTR_ID) {
@@ -436,7 +437,7 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
                 wxColor inactiveColor = GetInactiveColor(sp);
                 ctrl->StyleSetForeground(sp.GetId() + 64, inactiveColor);
                 ctrl->StyleSetFont(sp.GetId() + 64, font);
-                ctrl->StyleSetSize(sp.GetId() + 64, size);
+                // ctrl->StyleSetSize(sp.GetId() + 64, size);
                 ctrl->StyleSetBackground(sp.GetId() + 64, defaultStyle.GetBgColour());
 
                 ctrl->StyleSetBackground(sp.GetId(), sp.GetBgColour());
@@ -474,18 +475,20 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
     wxColour textColour = IsDark() ? *wxWHITE : *wxBLACK;
     ctrl->StyleSetBackground(ANNOTATION_STYLE_WARNING, defaultStyle.GetBgColour());
     ctrl->StyleSetForeground(ANNOTATION_STYLE_WARNING, textColour);
-    ctrl->StyleSetSizeFractional(ANNOTATION_STYLE_WARNING, (ctrl->StyleGetSizeFractional(wxSTC_STYLE_DEFAULT) * 4) / 5);
+    // ctrl->StyleSetSizeFractional(ANNOTATION_STYLE_WARNING, (ctrl->StyleGetSizeFractional(wxSTC_STYLE_DEFAULT) * 4) /
+    // 5);
 
     // Error style
     ctrl->StyleSetBackground(ANNOTATION_STYLE_ERROR, defaultStyle.GetBgColour());
     ctrl->StyleSetForeground(ANNOTATION_STYLE_ERROR, textColour);
-    ctrl->StyleSetSizeFractional(ANNOTATION_STYLE_ERROR, (ctrl->StyleGetSizeFractional(wxSTC_STYLE_DEFAULT) * 4) / 5);
+    // ctrl->StyleSetSizeFractional(ANNOTATION_STYLE_ERROR, (ctrl->StyleGetSizeFractional(wxSTC_STYLE_DEFAULT) * 4) /
+    // 5);
 
     // Code completion errors
     ctrl->StyleSetBackground(ANNOTATION_STYLE_CC_ERROR, defaultStyle.GetBgColour());
     ctrl->StyleSetForeground(ANNOTATION_STYLE_CC_ERROR, textColour);
-    ctrl->StyleSetSizeFractional(ANNOTATION_STYLE_CC_ERROR,
-                                 (ctrl->StyleGetSizeFractional(wxSTC_STYLE_DEFAULT) * 4) / 5);
+    // ctrl->StyleSetSizeFractional(ANNOTATION_STYLE_CC_ERROR,
+    //                             (ctrl->StyleGetSizeFractional(wxSTC_STYLE_DEFAULT) * 4) / 5);
 
     // annotation style 'boxed'
     ctrl->AnnotationSetVisible(wxSTC_ANNOTATION_BOXED);
@@ -502,6 +505,7 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
     // Overide TAB vs Space settings incase the file is a makefile
     // It is not an option for Makefile to use SPACES
     if(GetName().Lower() == "makefile") { ctrl->SetUseTabs(true); }
+    ctrl->SetLayoutCache(wxSTC_CACHE_PAGE);
 }
 
 const StyleProperty& LexerConf::GetProperty(int propertyId) const
