@@ -205,7 +205,7 @@ public:
      * @brief return the font for a given style id
      * @return return wxNullFont if error occurred or could locate the style
      */
-    wxFont GetFontForSyle(int styleId) const;
+    wxFont GetFontForSyle(int styleId, const wxWindow* win) const;
 };
 
 #endif // LEXER_CONFIGURATION_H
