@@ -57,48 +57,26 @@ LocalOptionsConfig::LocalOptionsConfig(OptionsConfigPtr opts, wxXmlNode* node)
         bool answer;
         wxString str;
         long l;
-        if(XmlUtils::ReadBoolIfExists(node, wxT("DisplayFoldMargin"), answer)) {
-            opts->SetDisplayFoldMargin(answer);
-        }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("DisplayFoldMargin"), answer)) { opts->SetDisplayFoldMargin(answer); }
         if(XmlUtils::ReadBoolIfExists(node, wxT("DisplayBookmarkMargin"), answer)) {
             opts->SetDisplayBookmarkMargin(answer);
         }
-        if(XmlUtils::ReadBoolIfExists(node, wxT("HighlightCaretLine"), answer)) {
-            opts->SetHighlightCaretLine(answer);
-        }
-        if(XmlUtils::ReadBoolIfExists(node, wxT("EditorTrimEmptyLines"), answer)) {
-            opts->SetTrimLine(answer);
-        }
-        if(XmlUtils::ReadBoolIfExists(node, wxT("EditorAppendLf"), answer)) {
-            opts->SetAppendLF(answer);
-        }
-        if(XmlUtils::ReadBoolIfExists(node, wxT("ShowLineNumber"), answer)) {
-            opts->SetDisplayLineNumbers(answer);
-        }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("HighlightCaretLine"), answer)) { opts->SetHighlightCaretLine(answer); }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("EditorTrimEmptyLines"), answer)) { opts->SetTrimLine(answer); }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("EditorAppendLf"), answer)) { opts->SetAppendLF(answer); }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("ShowLineNumber"), answer)) { opts->SetDisplayLineNumbers(answer); }
         if(XmlUtils::ReadBoolIfExists(node, wxT("IndentationGuides"), answer)) {
             opts->SetShowIndentationGuidelines(answer);
         }
-        if(XmlUtils::ReadBoolIfExists(node, wxT("IndentUsesTabs"), answer)) {
-            opts->SetIndentUsesTabs(answer);
-        }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("IndentUsesTabs"), answer)) { opts->SetIndentUsesTabs(answer); }
         if(XmlUtils::ReadBoolIfExists(node, wxT("HideChangeMarkerMargin"), answer)) {
             opts->SetHideChangeMarkerMargin(answer);
         }
-        if(XmlUtils::ReadLongIfExists(node, wxT("IndentWidth"), l)) {
-            opts->SetIndentWidth(l);
-        }
-        if(XmlUtils::ReadLongIfExists(node, wxT("TabWidth"), l)) {
-            opts->SetTabWidth(l);
-        }
-        if(XmlUtils::ReadLongIfExists(node, wxT("ShowWhitespaces"), l)) {
-            opts->SetShowWhitspaces(l);
-        }
-        if(XmlUtils::ReadStringIfExists(node, wxT("EOLMode"), str)) {
-            opts->SetEolMode(str);
-        }
-        if(XmlUtils::ReadStringIfExists(node, wxT("FileFontEncoding"), str)) {
-            opts->SetFileFontEncoding(str);
-        }
+        if(XmlUtils::ReadLongIfExists(node, wxT("IndentWidth"), l)) { opts->SetIndentWidth(l); }
+        if(XmlUtils::ReadLongIfExists(node, wxT("TabWidth"), l)) { opts->SetTabWidth(l); }
+        if(XmlUtils::ReadLongIfExists(node, wxT("ShowWhitespaces"), l)) { opts->SetShowWhitspaces(l); }
+        if(XmlUtils::ReadStringIfExists(node, wxT("EOLMode"), str)) { opts->SetEolMode(str); }
+        if(XmlUtils::ReadStringIfExists(node, wxT("FileFontEncoding"), str)) { opts->SetFileFontEncoding(str); }
     }
 }
 
@@ -113,48 +91,26 @@ LocalOptionsConfig::LocalOptionsConfig(LocalOptionsConfigPtr opts, wxXmlNode* no
         bool answer;
         wxString str;
         long l;
-        if(XmlUtils::ReadBoolIfExists(node, wxT("DisplayFoldMargin"), answer)) {
-            opts->SetDisplayFoldMargin(answer);
-        }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("DisplayFoldMargin"), answer)) { opts->SetDisplayFoldMargin(answer); }
         if(XmlUtils::ReadBoolIfExists(node, wxT("DisplayBookmarkMargin"), answer)) {
             opts->SetDisplayBookmarkMargin(answer);
         }
-        if(XmlUtils::ReadBoolIfExists(node, wxT("HighlightCaretLine"), answer)) {
-            opts->SetHighlightCaretLine(answer);
-        }
-        if(XmlUtils::ReadBoolIfExists(node, wxT("EditorTrimEmptyLines"), answer)) {
-            opts->SetTrimLine(answer);
-        }
-        if(XmlUtils::ReadBoolIfExists(node, wxT("EditorAppendLf"), answer)) {
-            opts->SetAppendLF(answer);
-        }
-        if(XmlUtils::ReadBoolIfExists(node, wxT("ShowLineNumber"), answer)) {
-            opts->SetDisplayLineNumbers(answer);
-        }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("HighlightCaretLine"), answer)) { opts->SetHighlightCaretLine(answer); }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("EditorTrimEmptyLines"), answer)) { opts->SetTrimLine(answer); }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("EditorAppendLf"), answer)) { opts->SetAppendLF(answer); }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("ShowLineNumber"), answer)) { opts->SetDisplayLineNumbers(answer); }
         if(XmlUtils::ReadBoolIfExists(node, wxT("IndentationGuides"), answer)) {
             opts->SetShowIndentationGuidelines(answer);
         }
-        if(XmlUtils::ReadBoolIfExists(node, wxT("IndentUsesTabs"), answer)) {
-            opts->SetIndentUsesTabs(answer);
-        }
+        if(XmlUtils::ReadBoolIfExists(node, wxT("IndentUsesTabs"), answer)) { opts->SetIndentUsesTabs(answer); }
         if(XmlUtils::ReadBoolIfExists(node, wxT("HideChangeMarkerMargin"), answer)) {
             opts->SetHideChangeMarkerMargin(answer);
         }
-        if(XmlUtils::ReadLongIfExists(node, wxT("IndentWidth"), l)) {
-            opts->SetIndentWidth(l);
-        }
-        if(XmlUtils::ReadLongIfExists(node, wxT("TabWidth"), l)) {
-            opts->SetTabWidth(l);
-        }
-        if(XmlUtils::ReadLongIfExists(node, wxT("ShowWhitespaces"), l)) {
-            opts->SetShowWhitespaces(l);
-        }
-        if(XmlUtils::ReadStringIfExists(node, wxT("EOLMode"), str)) {
-            opts->SetEolMode(str);
-        }
-        if(XmlUtils::ReadStringIfExists(node, wxT("FileFontEncoding"), str)) {
-            opts->SetFileFontEncoding(str);
-        }
+        if(XmlUtils::ReadLongIfExists(node, wxT("IndentWidth"), l)) { opts->SetIndentWidth(l); }
+        if(XmlUtils::ReadLongIfExists(node, wxT("TabWidth"), l)) { opts->SetTabWidth(l); }
+        if(XmlUtils::ReadLongIfExists(node, wxT("ShowWhitespaces"), l)) { opts->SetShowWhitespaces(l); }
+        if(XmlUtils::ReadStringIfExists(node, wxT("EOLMode"), str)) { opts->SetEolMode(str); }
+        if(XmlUtils::ReadStringIfExists(node, wxT("FileFontEncoding"), str)) { opts->SetFileFontEncoding(str); }
     }
 }
 
@@ -179,12 +135,8 @@ wxXmlNode* LocalOptionsConfig::ToXml(wxXmlNode* parent /*=NULL*/, const wxString
     if(HighlightCaretLineIsValid()) {
         n->AddProperty(wxT("HighlightCaretLine"), BoolToString(m_localhighlightCaretLine.GetDatum()));
     }
-    if(TrimLineIsValid()) {
-        n->AddProperty(wxT("EditorTrimEmptyLines"), BoolToString(m_localTrimLine.GetDatum()));
-    }
-    if(AppendLFIsValid()) {
-        n->AddProperty(wxT("EditorAppendLf"), BoolToString(m_localAppendLF.GetDatum()));
-    }
+    if(TrimLineIsValid()) { n->AddProperty(wxT("EditorTrimEmptyLines"), BoolToString(m_localTrimLine.GetDatum())); }
+    if(AppendLFIsValid()) { n->AddProperty(wxT("EditorAppendLf"), BoolToString(m_localAppendLF.GetDatum())); }
     if(DisplayLineNumbersIsValid()) {
         n->AddProperty(wxT("ShowLineNumber"), BoolToString(m_localdisplayLineNumbers.GetDatum()));
     }
@@ -198,9 +150,7 @@ wxXmlNode* LocalOptionsConfig::ToXml(wxXmlNode* parent /*=NULL*/, const wxString
         n->AddProperty(wxT("HideChangeMarkerMargin"), BoolToString(m_localhideChangeMarkerMargin.GetDatum()));
     }
 
-    if(EolModeIsValid()) {
-        n->AddProperty(wxT("EOLMode"), m_localeolMode.GetDatum());
-    }
+    if(EolModeIsValid()) { n->AddProperty(wxT("EOLMode"), m_localeolMode.GetDatum()); }
 
     wxString tmp;
     if(IndentWidthIsValid()) {
@@ -241,9 +191,7 @@ void LocalOptionsConfig::SetFileFontEncoding(const wxString& strFileFontEncoding
 void LocalWorkspace::GetOptions(OptionsConfigPtr options, const wxString& projectname)
 {
     // First, a SanityCheck(). This protects against a change of workspace, and calls Create() if needed
-    if(!SanityCheck()) {
-        return;
-    }
+    if(!SanityCheck()) { return; }
 
     // Get any workspace-wide preferences, then any project ones
     wxXmlNode* lwsnode = GetLocalWorkspaceOptionsNode();
@@ -253,9 +201,7 @@ void LocalWorkspace::GetOptions(OptionsConfigPtr options, const wxString& projec
     }
 
     wxXmlNode* lpnode = GetLocalProjectOptionsNode(projectname);
-    if(lpnode) {
-        LocalOptionsConfig pOC(options, lpnode);
-    }
+    if(lpnode) { LocalOptionsConfig pOC(options, lpnode); }
 
     // This space intentionally left blank :p  Maybe, one day there'll be individual-editor options too
 }
@@ -267,9 +213,7 @@ bool LocalWorkspace::SetWorkspaceOptions(LocalOptionsConfigPtr opts)
     //		<LocalWorkspaceOptions something="on" something_else="off"/>
     //	</Workspace>
 
-    if(!SanityCheck()) {
-        return false;
-    }
+    if(!SanityCheck()) { return false; }
 
     wxXmlNode* oldOptions = GetLocalWorkspaceOptionsNode();
     if(oldOptions) {
@@ -287,9 +231,7 @@ bool LocalWorkspace::SetProjectOptions(LocalOptionsConfigPtr opts, const wxStrin
     //		<Options something="on" something_else="off"/>
     //	</Project>
 
-    if(!SanityCheck()) {
-        return false;
-    }
+    if(!SanityCheck()) { return false; }
 
     // If the project node doesn't exist, create it
     wxXmlNode* project = XmlUtils::FindNodeByName(m_doc.GetRoot(), wxT("Project"), projectname);
@@ -331,9 +273,7 @@ bool LocalWorkspace::SanityCheck()
     localFile = localWspFile.GetFullPath();
     globalFile = workspaceFile.GetFullPath();
 
-    if((localFile == globalFile) && m_doc.IsOk()) {
-        return true;
-    }
+    if((localFile == globalFile) && m_doc.IsOk()) { return true; }
 
     // If we're here, the class isn't correctly set up, so
     return Create();
@@ -377,17 +317,13 @@ void LocalWorkspace::GetParserPaths(wxArrayString& inclduePaths, wxArrayString&
             if(child->GetName() == wxT("Exclude")) {
                 wxString path = child->GetPropVal(wxT("Path"), wxT(""));
                 path.Trim().Trim(false);
-                if(path.IsEmpty() == false) {
-                    excludePaths.Add(path);
-                }
+                if(path.IsEmpty() == false) { excludePaths.Add(path); }
             }
 
             else if(child->GetName() == wxT("Include")) {
                 wxString path = child->GetPropVal(wxT("Path"), wxT(""));
                 path.Trim().Trim(false);
-                if(path.IsEmpty() == false) {
-                    inclduePaths.Add(path);
-                }
+                if(path.IsEmpty() == false) { inclduePaths.Add(path); }
             }
 
             child = child->GetNext();
@@ -422,9 +358,7 @@ size_t LocalWorkspace::GetParserFlags()
     if(!SanityCheck()) return 0;
 
     wxXmlNode* node = XmlUtils::FindFirstByTagName(m_doc.GetRoot(), wxT("WorkspaceParserFlags"));
-    if(node) {
-        return XmlUtils::ReadLong(node, "flags", 0);
-    }
+    if(node) { return XmlUtils::ReadLong(node, "flags", 0); }
     return 0;
 }
 
@@ -433,9 +367,7 @@ void LocalWorkspace::SetParserFlags(size_t flags)
     if(!SanityCheck()) return;
 
     wxXmlNode* node = XmlUtils::FindFirstByTagName(m_doc.GetRoot(), wxT("WorkspaceParserFlags"));
-    if(!node) {
-        node = new wxXmlNode(m_doc.GetRoot(), wxXML_ELEMENT_NODE, wxT("WorkspaceParserFlags"));
-    }
+    if(!node) { node = new wxXmlNode(m_doc.GetRoot(), wxXML_ELEMENT_NODE, wxT("WorkspaceParserFlags")); }
 
     XmlUtils::UpdateProperty(node, "flags", wxString() << flags);
     SaveXmlFile();
@@ -447,9 +379,7 @@ wxString LocalWorkspace::GetActiveEnvironmentSet()
 
     wxXmlNode* envNode = XmlUtils::FindFirstByTagName(m_doc.GetRoot(), wxT("Environment"));
     wxString setName;
-    if(envNode) {
-        setName = envNode->GetPropVal(wxT("Name"), wxT(""));
-    }
+    if(envNode) { setName = envNode->GetPropVal(wxT("Name"), wxT("")); }
     return setName;
 }
 
@@ -467,23 +397,6 @@ void LocalWorkspace::SetActiveEnvironmentSet(const wxString& setName)
     SaveXmlFile();
 }
 
-static LocalWorkspace* gs_LocalWorkspace = NULL;
-void LocalWorkspaceST::Free()
-{
-    if(gs_LocalWorkspace) {
-        delete gs_LocalWorkspace;
-        gs_LocalWorkspace = NULL;
-    }
-}
-
-LocalWorkspace* LocalWorkspaceST::Get()
-{
-    if(gs_LocalWorkspace == NULL) {
-        gs_LocalWorkspace = new LocalWorkspace();
-    }
-    return gs_LocalWorkspace;
-}
-
 void LocalWorkspace::GetParserMacros(wxString& macros)
 {
     if(!SanityCheck()) return;
@@ -584,9 +497,7 @@ bool LocalWorkspace::SetFolderColours(const FolderColour::Map_t& vdColours)
     //     <VirtualFolder Path=".." Colour=".."/>
     //     ...
     // </VirtualFoldersColours>
-    if(!SanityCheck()) {
-        return false;
-    }
+    if(!SanityCheck()) { return false; }
 
     wxXmlNode* root = m_doc.GetRoot();
     wxXmlNode* oldOptions = XmlUtils::FindFirstByTagName(root, wxT("VirtualFoldersColours"));
@@ -618,9 +529,7 @@ bool LocalWorkspace::GetFolderColours(FolderColour::Map_t& vdColours)
     //     ...
     // </VirtualFoldersColours>
     vdColours.clear();
-    if(!SanityCheck()) {
-        return false;
-    }
+    if(!SanityCheck()) { return false; }
 
     wxXmlNode* coloursNode = XmlUtils::FindFirstByTagName(m_doc.GetRoot(), "VirtualFoldersColours");
     if(!coloursNode) return true;
@@ -635,3 +544,42 @@ bool LocalWorkspace::GetFolderColours(FolderColour::Map_t& vdColours)
     }
     return true;
 }
+
+size_t LocalWorkspace::GetPinnedProjects(wxArrayString& projects)
+{
+    projects.clear();
+    if(!SanityCheck()) { return 0; }
+
+    wxXmlNode* node = XmlUtils::FindFirstByTagName(m_doc.GetRoot(), "PinnedProjects");
+    if(!node) return 0;
+
+    // Read all projects
+    wxXmlNode* child = node->GetChildren();
+    while(child) {
+        if(child->GetName() == "Project") { projects.Add(child->GetAttribute("Name")); }
+        child = child->GetNext();
+    }
+    return projects.size();
+}
+
+bool LocalWorkspace::SetPinnedProjects(const wxArrayString& projects)
+{
+    if(!SanityCheck()) { return false; }
+
+    wxXmlNode* root = m_doc.GetRoot();
+    wxXmlNode* node = XmlUtils::FindFirstByTagName(root, wxT("PinnedProjects"));
+    if(node) {
+        root->RemoveChild(node);
+        wxDELETE(node);
+    }
+
+    node = new wxXmlNode(root, wxXML_ELEMENT_NODE, wxT("PinnedProjects"));
+    root->AddChild(node);
+
+    for(const wxString& project : projects) {
+        wxXmlNode* p = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Project"));
+        p->AddAttribute("Name", project);
+        node->AddChild(p);
+    }
+    return SaveXmlFile();
+}
