@@ -43,6 +43,7 @@
 #include <wx/imaglist.h>
 #include <wx/wupdlock.h>
 #include <wx/xrc/xmlres.h>
+#include "clFileSystemWorkspace.hpp"
 
 BEGIN_EVENT_TABLE(OpenResourceDialog, OpenResourceDialogBase)
 EVT_TIMER(XRCID("OR_TIMER"), OpenResourceDialog::OnTimer)
@@ -54,9 +55,8 @@ OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, cons
     , m_needRefresh(false)
     , m_lineNumber(wxNOT_FOUND)
 {
-    Hide();
     m_dataview->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
-    
+
     // initialize the file-type hash
     m_fileTypeHash["class"] = BitmapLoader::kClass;
     m_fileTypeHash["struct"] = BitmapLoader::kStruct;
@@ -89,26 +89,30 @@ OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, cons
     m_textCtrlResourceName->SetFocus();
     SetLabel(_("Open resource..."));
 
-    SetMinClientSize(wxSize(600, 400));
-    GetSizer()->Fit(this);
-
     SetName("OpenResourceDialog");
     WindowAttrManager::Load(this);
 
     // load all files from the workspace
-    if(m_manager->IsWorkspaceOpen()) {
-        wxArrayString projects;
-        m_manager->GetWorkspace()->GetProjectList(projects);
+    if(::clIsCxxWorkspaceOpened()) {
+        if(m_manager->IsWorkspaceOpen()) {
+            wxArrayString projects;
+            m_manager->GetWorkspace()->GetProjectList(projects);
 
-        for(size_t i = 0; i < projects.GetCount(); i++) {
-            ProjectPtr p = m_manager->GetWorkspace()->GetProject(projects.Item(i));
-            if(p) {
-                const Project::FilesMap_t& files = p->GetFiles();
-                // convert std::vector to wxArrayString
-                std::for_each(files.begin(), files.end(), [&](const Project::FilesMap_t::value_type& vt) {
-                    wxFileName fn(vt.second->GetFilename());
-                    m_files.insert(std::make_pair(fn.GetFullName(), fn.GetFullPath()));
-                });
+            for(size_t i = 0; i < projects.GetCount(); i++) {
+                ProjectPtr p = m_manager->GetWorkspace()->GetProject(projects.Item(i));
+                if(p) {
+                    const Project::FilesMap_t& files = p->GetFiles();
+                    // convert std::vector to wxArrayString
+                    std::for_each(files.begin(), files.end(), [&](const Project::FilesMap_t::value_type& vt) {
+                        wxFileName fn(vt.second->GetFilename());
+                        m_files.insert(std::make_pair(fn.GetFullName(), fn.GetFullPath()));
+                    });
+                }
+            }
+        } else if(clFileSystemWorkspace::Get().IsOpen()) {
+            const std::vector<wxFileName>& files = clFileSystemWorkspace::Get().GetFiles();
+            for(const wxFileName& fn : files) {
+                m_files.insert({ fn.GetFullName(), fn.GetFullPath() });
             }
         }
     }
@@ -128,7 +132,6 @@ OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, cons
     bool showSymbols = clConfig::Get().Read("OpenResourceDialog/ShowSymbols", true);
     m_checkBoxFiles->SetValue(showFiles);
     m_checkBoxShowSymbols->SetValue(showSymbols);
-    CentreOnParent();
     ::clSetDialogBestSizeAndPosition(this);
 }
 
@@ -177,8 +180,6 @@ void OpenResourceDialog::DoPopulateList()
 
     Clear();
 
-    wxWindowUpdateLocker locker(m_dataview);
-
     // First add the workspace files
     long nLineNumber;
     wxString modFilter;
@@ -269,11 +270,10 @@ void OpenResourceDialog::DoPopulateWorkspaceFile()
 void OpenResourceDialog::Clear()
 {
     // list control does not own the client data, we need to free it ourselves
-    for(size_t i = 0; i < m_dataview->GetItemCount(); ++i) {
-        OpenResourceDialogItemData* cd = GetItemData(m_dataview->RowToItem(i));
+    m_dataview->DeleteAllItems([](wxUIntPtr ptr) {
+        OpenResourceDialogItemData* cd = reinterpret_cast<OpenResourceDialogItemData*>(ptr);
         wxDELETE(cd);
-    }
-    m_dataview->DeleteAllItems();
+    });
     m_userFilters.Clear();
 }
 
@@ -302,18 +302,19 @@ void OpenResourceDialog::OnKeyDown(wxKeyEvent& event)
     if(event.GetKeyCode() == WXK_DOWN || event.GetKeyCode() == WXK_UP || event.GetKeyCode() == WXK_NUMPAD_UP ||
        event.GetKeyCode() == WXK_NUMPAD_DOWN) {
         event.Skip(false);
-        bool down = (event.GetKeyCode() == WXK_DOWN || event.GetKeyCode() == WXK_NUMPAD_DOWN);
-        wxDataViewItem selection = m_dataview->GetSelection();
-        if(!selection.IsOk()) {
-            // No selection, select the first
-            DoSelectItem(m_dataview->RowToItem(0));
+
+        if(GetDataview()->GetSelectedItemsCount() == 0) {
+            // Just select the first entry
+            DoSelectItem(GetDataview()->RowToItem(0));
         } else {
-            int curIndex = m_dataview->ItemToRow(selection);
-            if(curIndex != wxNOT_FOUND) {
-                down ? ++curIndex : --curIndex;
-                DoSelectItem(m_dataview->RowToItem(curIndex));
-            }
+            // fire char hook event to the DV control
+            // so it will handle the keyboard movement itself
+            wxKeyEvent charHook = event;
+            charHook.SetEventObject(m_dataview);
+            charHook.SetEventType(wxEVT_CHAR_HOOK);
+            GetDataview()->GetEventHandler()->ProcessEvent(charHook);
         }
+
         // Set the focus back to the text control
         m_textCtrlResourceName->CallAfter(&wxTextCtrl::SetFocus);
     }
@@ -328,8 +329,9 @@ bool OpenResourceDialogItemData::IsOk() const { return m_file.IsEmpty() == false
 void OpenResourceDialog::DoSelectItem(const wxDataViewItem& item)
 {
     CHECK_ITEM_RET(item);
-    m_dataview->Select(item);
-    m_dataview->EnsureVisible(item);
+    GetDataview()->Select(item);
+    GetDataview()->EnsureVisible(item);
+    GetDataview()->Refresh();
 }
 
 void OpenResourceDialog::DoAppendLine(const wxString& name, const wxString& fullname, bool boldFont,
@@ -352,7 +354,7 @@ void OpenResourceDialog::OnTimer(wxTimerEvent& event)
 
     // If there is only 1 item in the resource window then highlight it.
     // This allows the user to hit ENTER immediately after to open the item, nice shortcut.
-    if(m_dataview->GetItemCount() == 1) { DoSelectItem(m_dataview->RowToItem(0)); }
+    if(m_dataview && m_dataview->GetItemCount() == 1) { DoSelectItem(m_dataview->RowToItem(0)); }
 }
 
 int OpenResourceDialog::DoGetTagImg(TagEntryPtr tag)
@@ -380,11 +382,7 @@ bool OpenResourceDialog::MatchesFilter(const wxString& name)
 void OpenResourceDialog::OnCheckboxfilesCheckboxClicked(wxCommandEvent& event) { DoPopulateList(); }
 void OpenResourceDialog::OnCheckboxshowsymbolsCheckboxClicked(wxCommandEvent& event) { DoPopulateList(); }
 
-void OpenResourceDialog::OnEnter(wxCommandEvent& event)
-{
-    event.Skip();
-    EndModal(wxID_OK);
-}
+void OpenResourceDialog::OnEnter(wxCommandEvent& event) { CallAfter(&OpenResourceDialog::EndModal, wxID_OK); }
 
 void OpenResourceDialog::OnEntrySelected(wxDataViewEvent& event) { event.Skip(); }
 
