@@ -48,6 +48,7 @@
 #include "localworkspace.h"
 #include "compiler_command_line_parser.h"
 #include "fileutils.h"
+#include <wx/sstream.h>
 
 clCxxWorkspace::clCxxWorkspace()
     : m_saveOnExit(true)
@@ -653,10 +654,14 @@ bool clCxxWorkspace::SaveXmlFile()
     // Set the workspace XML version
     wxString version;
     if(!m_doc.GetRoot()->GetAttribute("Version", &version)) {
-        m_doc.GetRoot()->AddAttribute("Version", WORKSPACE_XML_VERSION);
+        m_doc.GetRoot()->AddAttribute("Version", DEFAULT_CURRENT_WORKSPACE_VERSION_STR);
     }
 
-    bool ok = m_doc.Save(m_fileName.GetFullPath());
+    wxString content;
+    wxStringOutputStream sos(&content);
+    m_doc.Save(sos);
+
+    bool ok = FileUtils::WriteFileContent(m_fileName, content);
     SetWorkspaceLastModifiedTime(GetFileLastModifiedTime());
     EventNotifier::Get()->PostFileSavedEvent(m_fileName.GetFullPath());
     DoUpdateBuildMatrix();
@@ -1004,7 +1009,7 @@ wxFileName clCxxWorkspace::GetTagsFileName() const
     return fn_tags;
 }
 
-cJSON* clCxxWorkspace::CreateCompileCommandsJSON() const
+cJSON* clCxxWorkspace::CreateCompileCommandsJSON(bool compile_flags_only) const
 {
     // Build the global compiler paths, we will need this later on...
     wxStringMap_t compilersGlobalPaths;
@@ -1026,47 +1031,48 @@ cJSON* clCxxWorkspace::CreateCompileCommandsJSON() const
     if(activeProject) {
         BuildConfigPtr buildConf = activeProject->GetBuildConfiguration();
         if(buildConf && buildConf->IsCustomBuild()) {
-            // Using custom build
-            wxString buildWorkingDirectory = MacroManager::Instance()->Expand(
-                buildConf->GetCustomBuildWorkingDir(), NULL, activeProject->GetName(), buildConf->GetName());
-            wxFileName fnWorkingDirectory(buildWorkingDirectory, "compile_commands.json");
-            if(fnWorkingDirectory.FileExists()) {
-
-                JSON root(fnWorkingDirectory);
-                if(root.isOk()) {
-                    JSON newFile(cJSON_Array);
-                    JSONItem newArr = newFile.toElement();
-                    JSONItem arr = root.toElement();
-                    int size = arr.arraySize();
-                    for(int i = 0; i < size; ++i) {
-                        JSONItem file = arr.arrayItem(i);
-                        wxString command = file.namedObject("command").toString();
-                        wxString file_name = file.namedObject("file").toString();
-                        wxString directory = file.namedObject("directory").toString();
-
-                        std::vector<wxString> files;
-                        files.push_back(file_name);
-
-                        wxFileName headerFile(file_name);
-                        headerFile.SetExt("h");
-                        if(headerFile.FileExists()) { files.push_back(headerFile.GetFullPath()); }
-                        
-                        // Create two entries: header & cpp (if the header exists)
-                        for(const wxString& filename : files) {
-                            JSONItem fileItem = JSONItem::createObject();
-                            fileItem.addProperty("file", filename).addProperty("directory", directory);
-
-                            // Fix the build command
-                            CompilerCommandLineParser cclp(command, directory);
-                            cclp.MakeAbsolute(directory);
-                            fileItem.addProperty("command",
-                                                 wxString() << "clang " << cclp.GetCompileLine() << " -c " << filename);
-                            newArr.arrayAppend(fileItem);
-                        }
-                    }
-                    return newFile.release();
-                }
-            }
+            //    // Using custom build
+            //    wxString buildWorkingDirectory = MacroManager::Instance()->Expand(
+            //        buildConf->GetCustomBuildWorkingDir(), NULL, activeProject->GetName(), buildConf->GetName());
+            //    wxFileName fnWorkingDirectory(buildWorkingDirectory, "compile_commands.json");
+            //    if(fnWorkingDirectory.FileExists()) {
+            //        JSON root(fnWorkingDirectory);
+            //        if(root.isOk()) {
+            //            JSON newFile(cJSON_Array);
+            //            JSONItem newArr = newFile.toElement();
+            //            JSONItem arr = root.toElement();
+            //            int size = arr.arraySize();
+            //            for(int i = 0; i < size; ++i) {
+            //                JSONItem file = arr.arrayItem(i);
+            //                wxString command = file.namedObject("command").toString();
+            //                wxString file_name = file.namedObject("file").toString();
+            //                wxString directory = file.namedObject("directory").toString();
+            //
+            //                std::vector<wxString> files;
+            //                files.push_back(file_name);
+            //
+            //                wxFileName headerFile(file_name);
+            //                headerFile.SetExt("h");
+            //                if(headerFile.FileExists()) { files.push_back(headerFile.GetFullPath()); }
+            //
+            //                // Create two entries: header & cpp (if the header exists)
+            //                for(const wxString& filename : files) {
+            //                    JSONItem fileItem = JSONItem::createObject();
+            //                    fileItem.addProperty("file", filename).addProperty("directory", directory);
+            //
+            //                    // Fix the build command
+            //                    CompilerCommandLineParser cclp(command, directory);
+            //                    cclp.MakeAbsolute(directory);
+            //                    fileItem.addProperty("command",
+            //                                         wxString() << "clang " << cclp.GetCompileLine() << " -c " <<
+            //                                         filename);
+            //                    newArr.arrayAppend(fileItem);
+            //                }
+            //            }
+            //            return newFile.release();
+            //        }
+            //    }
+            return nullptr;
         }
     }
 
@@ -1076,10 +1082,10 @@ cJSON* clCxxWorkspace::CreateCompileCommandsJSON() const
         BuildConfigPtr buildConf = iter->second->GetBuildConfiguration();
         if(buildConf && buildConf->IsProjectEnabled() && !buildConf->IsCustomBuild() &&
            buildConf->IsCompilerRequired()) {
-            iter->second->CreateCompileCommandsJSON(compile_commands, compilersGlobalPaths);
+            iter->second->CreateCompileCommandsJSON(compile_commands, compilersGlobalPaths, compile_flags_only);
         }
     }
-    return compile_commands.release();
+    return compile_flags_only ? nullptr : compile_commands.release();
 }
 
 ProjectPtr clCxxWorkspace::GetActiveProject() const { return GetProject(GetActiveProjectName()); }
