@@ -56,6 +56,7 @@
 #include "file_logger.h"
 #include "SFTPGrep.h"
 #include "SFTPStatusPage.h"
+#include <wx/utils.h>
 
 static const int ID_NEW = ::wxNewId();
 static const int ID_RENAME = ::wxNewId();
@@ -75,7 +76,10 @@ SFTPTreeView::SFTPTreeView(wxWindow* parent, SFTP* plugin)
 {
     m_bmpLoader = clGetManager()->GetStdIcons();
     m_treeCtrl->SetBitmaps(m_bmpLoader->GetStandardMimeBitmapListPtr());
-
+    m_timer = new wxTimer(this);
+    Bind(wxEVT_TIMER, &SFTPTreeView::OnKeepAliveTimer, this, m_timer->GetId());
+    m_timer->Start(30000); // every 30 seconds send a hearbeat
+    
     std::function<bool(const wxTreeItemId&, const wxTreeItemId&)> SortFunc = [&](const wxTreeItemId& itemA,
                                                                                  const wxTreeItemId& itemB) {
         MyClientData* a = static_cast<MyClientData*>(GetItemData(itemA));
@@ -160,6 +164,9 @@ SFTPTreeView::~SFTPTreeView()
     m_treeCtrl->Disconnect(ID_REFRESH_FOLDER, wxEVT_MENU, wxCommandEventHandler(SFTPTreeView::OnMenuRefreshFolder),
                            NULL, this);
     Unbind(wxEVT_DND_FILE_DROPPED, &SFTPTreeView::OnFileDropped, this);
+    m_timer->Stop();
+    Unbind(wxEVT_TIMER, &SFTPTreeView::OnKeepAliveTimer, this, m_timer->GetId());
+    wxDELETE(m_timer);
 }
 
 void SFTPTreeView::OnDisconnect(wxCommandEvent& event) { DoCloseSession(); }
@@ -170,7 +177,7 @@ void SFTPTreeView::DoBuildTree(const wxString& initialFolder)
     m_treeCtrl->DeleteAllItems();
     // add the root item
     MyClientData* cd = new MyClientData(initialFolder);
-    cd->SetIsFolder(true);
+    cd->SetFolder();
 
     wxTreeItemId root =
         m_treeCtrl->AddRoot(initialFolder, m_bmpLoader->GetMimeImageId(FileExtManager::TypeFolder), wxNOT_FOUND, cd);
@@ -192,9 +199,8 @@ void SFTPTreeView::OnItemActivated(wxTreeEvent& event)
         } else {
             m_treeCtrl->CallAfter(&clThemedTreeCtrl::Expand, item);
         }
-
     } else {
-        DoOpenFile(cd->GetFullPath());
+        DoOpenFile(cd->IsSymlink() ? cd->GetSymlinkTarget() : cd->GetFullPath());
     }
 }
 
@@ -206,11 +212,7 @@ void SFTPTreeView::OnItemExpanding(wxTreeEvent& event)
 void SFTPTreeView::OnOpenAccountManager(wxCommandEvent& event)
 {
     SSHAccountManagerDlg dlg(EventNotifier::Get()->TopFrame());
-    if(dlg.ShowModal() == wxID_OK) {
-        SFTPSettings settings;
-        settings.Load().SetAccounts(dlg.GetAccounts());
-        settings.Save();
-    }
+    dlg.ShowModal();
 }
 
 void SFTPTreeView::DoCloseSession()
@@ -251,6 +253,7 @@ void SFTPTreeView::DoCloseSession()
 
 bool SFTPTreeView::DoExpandItem(const wxTreeItemId& item)
 {
+    wxBusyCursor bc;
     MyClientData* cd = GetItemData(item);
     CHECK_PTR_RET_FALSE(cd);
 
@@ -260,7 +263,8 @@ bool SFTPTreeView::DoExpandItem(const wxTreeItemId& item)
     // get list of files and populate the tree
     SFTPAttribute::List_t attributes;
     try {
-        attributes = m_sftp->List(cd->GetFullPath(), clSFTP::SFTP_BROWSE_FILES | clSFTP::SFTP_BROWSE_FOLDERS);
+        attributes = m_sftp->List(cd->IsSymlink() ? cd->GetSymlinkTarget() : cd->GetFullPath(),
+                                  clSFTP::SFTP_BROWSE_FILES | clSFTP::SFTP_BROWSE_FOLDERS);
 
     } catch(clException& e) {
         ::wxMessageBox(e.What(), "SFTP", wxOK | wxICON_ERROR | wxCENTER, EventNotifier::Get()->TopFrame());
@@ -274,6 +278,7 @@ bool SFTPTreeView::DoExpandItem(const wxTreeItemId& item)
     cd->SetInitialized(true);
 
     int nNumOfRealChildren = 0;
+
     SFTPAttribute::List_t::iterator iter = attributes.begin();
     for(; iter != attributes.end(); ++iter) {
         SFTPAttribute::Ptr_t attr = (*iter);
@@ -282,13 +287,24 @@ bool SFTPTreeView::DoExpandItem(const wxTreeItemId& item)
         ++nNumOfRealChildren;
         // determine the icon index
         int imgIdx = wxNOT_FOUND;
+        int expandImgIDx = wxNOT_FOUND;
         if(attr->IsFolder()) {
             imgIdx = m_bmpLoader->GetMimeImageId(FileExtManager::TypeFolder);
-
-        } else {
+            expandImgIDx = m_bmpLoader->GetMimeImageId(FileExtManager::TypeFolderExpanded);
+        } else if(attr->IsFile()) {
             imgIdx = m_bmpLoader->GetMimeImageId(attr->GetName());
         }
 
+        if(attr->IsSymlink()) {
+            if(attr->IsFile()) {
+                imgIdx = m_bmpLoader->GetMimeImageId(FileExtManager::TypeFileSymlink);
+
+            } else {
+                imgIdx = m_bmpLoader->GetMimeImageId(FileExtManager::TypeFolderSymlink);
+                expandImgIDx = m_bmpLoader->GetMimeImageId(FileExtManager::TypeFolderSymlinkExpanded);
+            }
+        }
+
         if(imgIdx == wxNOT_FOUND) { imgIdx = m_bmpLoader->GetMimeImageId(FileExtManager::TypeText); }
 
         wxString path;
@@ -296,9 +312,18 @@ bool SFTPTreeView::DoExpandItem(const wxTreeItemId& item)
         while(path.Replace("//", "/")) {}
 
         MyClientData* childClientData = new MyClientData(path);
-        childClientData->SetIsFolder(attr->IsFolder());
+        if(attr->IsFolder()) {
+            childClientData->SetFolder();
+        } else if(attr->IsFile()) {
+            childClientData->SetFile();
+        }
 
-        wxTreeItemId child = m_treeCtrl->AppendItem(item, attr->GetName(), imgIdx, imgIdx, childClientData);
+        if(attr->IsSymlink()) {
+            childClientData->SetSymlink();
+            childClientData->SetSymlinkTarget(attr->GetSymlinkPath());
+        }
+
+        wxTreeItemId child = m_treeCtrl->AppendItem(item, attr->GetName(), imgIdx, expandImgIDx, childClientData);
         // if its type folder, add a fake child item
         if(attr->IsFolder()) { m_treeCtrl->AppendItem(child, "<dummy>"); }
     }
@@ -499,7 +524,7 @@ wxTreeItemId SFTPTreeView::DoAddFile(const wxTreeItemId& parent, const wxString&
         SFTPAttribute::Ptr_t attr = m_sftp->Stat(path);
         // Update the UI
         MyClientData* newFile = new MyClientData(path);
-        newFile->SetIsFolder(false);
+        newFile->SetFile();
         newFile->SetInitialized(false);
 
         wxTreeItemId child = m_treeCtrl->AppendItem(
@@ -520,7 +545,7 @@ wxTreeItemId SFTPTreeView::DoAddFolder(const wxTreeItemId& parent, const wxStrin
         SFTPAttribute::Ptr_t attr = m_sftp->Stat(path);
         // Update the UI
         MyClientData* newCd = new MyClientData(path);
-        newCd->SetIsFolder(true);
+        newCd->SetFolder();
         newCd->SetInitialized(false);
 
         wxTreeItemId child = m_treeCtrl->AppendItem(
@@ -546,7 +571,7 @@ void SFTPTreeView::OnAddBookmarkMenu(wxCommandEvent& event)
     menu.AppendSeparator();
     menu.Append(ID_SFTP_BOOKMARK_SETTINGS, _("Manage bookmarks..."));
 
-    int sel = m_toolbar->GetMenuSelectionFromUser(XRCID("ID_SFTP_BOOKMARK_SETTINGS"), &menu);
+    int sel = m_toolbar->GetMenuSelectionFromUser(XRCID("ID_ADD_BOOKMARK"), &menu);
     if((sel >= ID_SFTP_BOOKMARK_FIRST) && (sel <= ID_SFTP_BOOKMARK_LAST)) {
         // A bookmark was selected
         CallAfter(&SFTPTreeView::DoBuildTree, bookmarks.Item(sel - ID_SFTP_BOOKMARK_FIRST));
@@ -1012,7 +1037,7 @@ void SFTPTreeView::OnRemoteFind(wxCommandEvent& event)
 
     try {
         if(m_channel && m_channel->IsOpen()) { m_channel->Close(); }
-        m_channel.reset(new clSSHChannel(m_sftp->GetSsh()));
+        m_channel.reset(new clSSHChannel(m_sftp->GetSsh(), clSSHChannel::kRemoteCommand, m_plugin->GetOutputPane()));
         m_channel->Open();
 
         // Prepare the UI for new search
@@ -1024,9 +1049,23 @@ void SFTPTreeView::OnRemoteFind(wxCommandEvent& event)
         GrepData gd = grep.GetData();
         wxString command = gd.GetGrepCommand(remoteFolder);
         m_plugin->GetOutputPane()->AddSearchText(wxString() << "Running command: " << command);
-        m_channel->Execute(command, m_plugin->GetOutputPane());
+        m_channel->Execute(command);
 
     } catch(clException& e) {
         ::wxMessageBox(e.What(), "SFTP", wxICON_ERROR | wxOK | wxCENTER);
     }
 }
+
+void SFTPTreeView::OnKeepAliveTimer(wxTimerEvent& event)
+{
+    wxUnusedVar(event);
+    if(IsConnected()) {
+        // Perform a minimal operation to keep our session alive
+        try {
+            m_sftp->Stat(".");
+            clDEBUG1() << "SFTP: Heartbeat successfully sent!";
+        } catch(clException& e) {
+            clGetManager()->SetStatusMessage(_("SFTP: session closed by the server"));
+        }
+    }
+}
