@@ -33,39 +33,52 @@
 // Copyright:   2014 Frank Lichtner
 // License:
 /////////////////////////////////////////////////////////////////////////////
-#include "wx/wxprec.h"
+#include "clToolBarButtonBase.h"
 #include "event_notifier.h"
+#include "globals.h"
+#include "wx/wxprec.h"
 #ifndef WX_PRECOMP
 #include "wx/wx.h"
 #endif
 
-#include "spellcheck.h"
-#include "workspace.h"
-#include "ctags_manager.h"
-#include "scGlobals.h"
 #include "IHunSpell.h"
 #include "SpellCheckerSettings.h"
+#include "ctags_manager.h"
+#include "scGlobals.h"
+#include "spellcheck.h"
+#include "workspace.h"
 
 #include <wx/mstream.h>
-#include <wx/xrc/xmlres.h>
-#include <wx/tokenzr.h>
 #include <wx/stc/stc.h>
+#include <wx/tokenzr.h>
+#include <wx/xrc/xmlres.h>
 
 #include "res/spellcheck16.b2c"
 #include "res/spellcheck22.b2c"
 //#include "res/contCheck16.b2c"
 //#include "res/contCheck22.b2c"
 
-static SpellCheck* thePlugin = NULL;
-#define SPC_BASEID 10000
-#define PARSE_TIME 500
+namespace
+{
+
+SpellCheck* thePlugin = NULL;
+
+constexpr size_t maxSuggestions = 15;
+
+const int SPC_IGNORE_WORD = XRCID("spellcheck_ignore_word");
+const int SPC_ADD_WORD = XRCID("spellcheck_add_word");
+const int SPC_SUGGESTION_ID = wxWindow::NewControlId(maxSuggestions);
+const int IDM_SETTINGS = XRCID("spellcheck_settings");
+
+constexpr int PARSE_TIME = 500;
+
+} // namespace
+
 // ------------------------------------------------------------
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new SpellCheck(manager);
-    }
+    if(thePlugin == 0) { thePlugin = new SpellCheck(manager); }
     return thePlugin;
 }
 // ------------------------------------------------------------
@@ -83,28 +96,31 @@ CL_PLUGIN_API int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION;
 // ------------------------------------------------------------
 SpellCheck::SpellCheck(IManager* manager)
     : IPlugin(manager)
+    , m_pLastEditor(nullptr)
 {
     Init();
 }
 // ------------------------------------------------------------
 SpellCheck::~SpellCheck()
 {
-    m_topWin->Disconnect(
-        IDM_SETTINGS, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(SpellCheck::OnSettings), NULL, this);
-    m_topWin->Disconnect(XRCID(s_doCheckID.ToUTF8()),
-                         wxEVT_COMMAND_MENU_SELECTED,
-                         wxCommandEventHandler(SpellCheck::OnCheck),
-                         NULL,
-                         this);
-    m_topWin->Disconnect(XRCID(s_contCheckID.ToUTF8()),
-                         wxEVT_COMMAND_MENU_SELECTED,
-                         wxCommandEventHandler(SpellCheck::OnContinousCheck),
-                         NULL,
-                         this);
-    m_timer.Disconnect(wxEVT_TIMER, wxTimerEventHandler(SpellCheck::OnTimer), NULL, this);
-    m_topWin->Disconnect(wxEVT_CMD_EDITOR_CONTEXT_MENU, wxCommandEventHandler(SpellCheck::OnContextMenu), NULL, this);
-    m_topWin->Disconnect(wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(SpellCheck::OnWspClosed), NULL, this);
-    if(m_pEngine != NULL) wxDELETE(m_pEngine);
+    m_timer.Unbind(wxEVT_TIMER, &SpellCheck::OnTimer, this);
+
+    m_topWin->Unbind(wxEVT_MENU, &SpellCheck::OnSettings, this, IDM_SETTINGS);
+    m_topWin->Unbind(wxEVT_MENU, &SpellCheck::OnCheck, this, XRCID(s_doCheckID.ToUTF8()));
+    m_topWin->Unbind(wxEVT_MENU, &SpellCheck::OnContinousCheck, this, XRCID(s_contCheckID.ToUTF8()));
+    m_topWin->Unbind(wxEVT_CONTEXT_MENU_EDITOR, &SpellCheck::OnContextMenu, this);
+    m_topWin->Unbind(wxEVT_WORKSPACE_LOADED, &SpellCheck::OnWspLoaded, this);
+    m_topWin->Unbind(wxEVT_WORKSPACE_CLOSED, &SpellCheck::OnWspClosed, this);
+
+    m_topWin->Unbind(wxEVT_MENU, &SpellCheck::OnSuggestion, this, SPC_SUGGESTION_ID,
+                     SPC_SUGGESTION_ID + maxSuggestions - 1);
+    m_topWin->Unbind(wxEVT_MENU, &SpellCheck::OnAddWord, this, SPC_ADD_WORD);
+    m_topWin->Unbind(wxEVT_MENU, &SpellCheck::OnIgnoreWord, this, SPC_IGNORE_WORD);
+
+    if(m_pEngine != NULL) {
+        SaveSettings();
+        wxDELETE(m_pEngine);
+    }
 }
 
 // ------------------------------------------------------------
@@ -115,9 +131,7 @@ void SpellCheck::Init()
     m_longName = _("CodeLite spell-checker");
     m_shortName = s_plugName;
     m_sepItem = NULL;
-    m_pToolbar = NULL;
     m_topWin = wxTheApp;
-    m_checkContinuous = false;
     m_pEngine = new IHunSpell();
     m_currentWspPath = wxEmptyString;
 
@@ -133,42 +147,30 @@ void SpellCheck::Init()
 
         if(!m_options.GetDictionaryFileName().IsEmpty()) m_pEngine->InitEngine();
     }
-    m_timer.Connect(wxEVT_TIMER, wxTimerEventHandler(SpellCheck::OnTimer), NULL, this);
-    m_topWin->Connect(wxEVT_CMD_EDITOR_CONTEXT_MENU, wxCommandEventHandler(SpellCheck::OnContextMenu), NULL, this);
-    m_topWin->Connect(wxEVT_WORKSPACE_LOADED, wxCommandEventHandler(SpellCheck::OnWspLoaded), NULL, this);
-    m_topWin->Connect(wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(SpellCheck::OnWspClosed), NULL, this);
-    EventNotifier::Get()->Bind(wxEVT_CONTEXT_MENU_EDITOR, &SpellCheck::OnEditorContextMenuShowing, this);
+    m_timer.Bind(wxEVT_TIMER, &SpellCheck::OnTimer, this);
+    m_topWin->Bind(wxEVT_CONTEXT_MENU_EDITOR, &SpellCheck::OnContextMenu, this);
+    m_topWin->Bind(wxEVT_WORKSPACE_LOADED, &SpellCheck::OnWspLoaded, this);
+    m_topWin->Bind(wxEVT_WORKSPACE_CLOSED, &SpellCheck::OnWspClosed, this);
+
+    m_topWin->Bind(wxEVT_MENU, &SpellCheck::OnSuggestion, this, SPC_SUGGESTION_ID,
+                   SPC_SUGGESTION_ID + maxSuggestions - 1);
+    m_topWin->Bind(wxEVT_MENU, &SpellCheck::OnAddWord, this, SPC_ADD_WORD);
+    m_topWin->Bind(wxEVT_MENU, &SpellCheck::OnIgnoreWord, this, SPC_IGNORE_WORD);
 }
 // ------------------------------------------------------------
-clToolBar* SpellCheck::CreateToolBar(wxWindow* parent)
+void SpellCheck::CreateToolBar(clToolBar* toolbar)
 {
-    if(m_mgr->AllowToolbar()) {
-        int size = m_mgr->GetToolbarIconSize();
-        m_pToolbar = new clToolBar(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, clTB_DEFAULT_STYLE_PLUGIN);
-        m_pToolbar->SetToolBitmapSize(wxSize(size, size));
-        m_pToolbar->AddTool(XRCID(s_doCheckID.ToUTF8()),
-                            _("Check spelling..."),
-                            m_mgr->GetStdIcons()->LoadBitmap("spellcheck", size),
-                            _("Run spell-checker"));
-        m_pToolbar->AddTool(XRCID(s_contCheckID.ToUTF8()),
-                            _("Check continuous"),
-                            m_mgr->GetStdIcons()->LoadBitmap("repeat", size),
-                            _("Run continuous check"),
-                            wxITEM_CHECK);
-        m_pToolbar->Realize();
-    }
-    parent->Connect(XRCID(s_doCheckID.ToUTF8()),
-                    wxEVT_COMMAND_MENU_SELECTED,
-                    wxCommandEventHandler(SpellCheck::OnCheck),
-                    NULL,
-                    this);
-    parent->Connect(XRCID(s_contCheckID.ToUTF8()),
-                    wxEVT_COMMAND_MENU_SELECTED,
-                    wxCommandEventHandler(SpellCheck::OnContinousCheck),
-                    NULL,
-                    this);
-    return m_pToolbar;
+    int size = m_mgr->GetToolbarIconSize();
+    toolbar->AddSpacer();
+    toolbar->AddTool(XRCID(s_doCheckID.ToUTF8()), _("Check spelling..."),
+                     m_mgr->GetStdIcons()->LoadBitmap("spellcheck", size), _("Run spell-checker"));
+    toolbar->AddToggleButton(XRCID(s_contCheckID.ToUTF8()), m_mgr->GetStdIcons()->LoadBitmap("repeat", size),
+                             _("Check continuous"));
+    wxTheApp->Bind(wxEVT_MENU, &SpellCheck::OnCheck, this, XRCID(s_doCheckID.ToUTF8()));
+    wxTheApp->Bind(wxEVT_MENU, &SpellCheck::OnContinousCheck, this, XRCID(s_contCheckID.ToUTF8()));
+    SetCheckContinuous(GetCheckContinuous());
 }
+
 // ------------------------------------------------------------
 void SpellCheck::CreatePluginMenu(wxMenu* pluginsMenu)
 {
@@ -179,40 +181,61 @@ void SpellCheck::CreatePluginMenu(wxMenu* pluginsMenu)
     pMenu->Append(pItem);
     pluginsMenu->Append(wxID_ANY, s_plugName, pMenu);
 
-    m_topWin->Connect(
-        IDM_SETTINGS, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(SpellCheck::OnSettings), NULL, this);
+    m_topWin->Bind(wxEVT_MENU, &SpellCheck::OnSettings, this, IDM_SETTINGS);
 }
 // ------------------------------------------------------------
-wxMenu* SpellCheck::CreateSubMenu()
+void SpellCheck::OnContextMenu(clContextMenuEvent& e)
 {
-    wxMenu* menu = new wxMenu();
+    const auto editor = GetEditor();
+    const auto menu = e.GetMenu();
+    if(!editor || !menu) { return; }
 
-    wxMenuItem* pItem(NULL);
-    pItem = new wxMenuItem(menu, XRCID(s_doCheckID.ToUTF8()), _("Check..."), _("Check..."), wxITEM_NORMAL);
-    menu->Append(pItem);
-    pItem = new wxMenuItem(
-        menu, XRCID(s_contCheckID.ToUTF8()), _("Check continuous"), _("Start continuous check"), wxITEM_CHECK);
-    menu->Append(pItem);
-    return menu;
+    const auto subMenuName(_("Spell Checker"));
+    auto pSubMenu(new wxMenu);
+
+    wxPoint pt = wxGetMousePosition();
+    pt = editor->GetCtrl()->ScreenToClient(pt);
+    const int pos = editor->GetCtrl()->PositionFromPoint(pt);
+
+    if(editor->GetCtrl()->IndicatorValueAt(3, pos) == 1) {
+        m_pLastEditor = nullptr;
+
+        int start = editor->WordStartPos(pos, true);
+        editor->SelectText(start, editor->WordEndPos(pos, true) - start);
+        wxString sel = editor->GetSelection();
+        wxArrayString sugg = m_pEngine->GetSuggestions(sel);
+
+        for(size_t i = 0; i < std::min<>(sugg.GetCount(), size_t(maxSuggestions)); i++) {
+            pSubMenu->Append(SPC_SUGGESTION_ID + i, sugg[i], "");
+        }
+
+        if(sugg.GetCount() != 0) { pSubMenu->AppendSeparator(); }
+
+        pSubMenu->Append(SPC_IGNORE_WORD, _("Ignore"), "");
+        pSubMenu->Append(SPC_ADD_WORD, _("Add"), "");
+
+        pSubMenu->AppendSeparator();
+        AppendSubMenuItems(*pSubMenu);
+
+        // Place at top of context menu for ease of access.
+        menu->PrependSeparator();
+        menu->Prepend(wxID_ANY, subMenuName, pSubMenu);
+    } else {
+        AppendSubMenuItems(*pSubMenu);
+        menu->Append(wxID_ANY, subMenuName, pSubMenu);
+    }
 }
 // ------------------------------------------------------------
-void SpellCheck::HookPopupMenu(wxMenu* menu, MenuType type)
+void SpellCheck::AppendSubMenuItems(wxMenu& subMenu)
 {
-    wxUnusedVar(menu);
-    wxUnusedVar(type);
+    subMenu.Append(XRCID(s_doCheckID.ToUTF8()), _("Check..."), _("Check..."));
+    subMenu.Append(XRCID(s_contCheckID.ToUTF8()), _("Check continuous"), _("Start continuous check"), wxITEM_CHECK);
+    subMenu.Check(XRCID(s_contCheckID.ToUTF8()), GetCheckContinuous());
+    subMenu.Append(IDM_SETTINGS, _("Settings..."), _("Settings..."), wxITEM_NORMAL);
 }
-
-// ------------------------------------------------------------
-void SpellCheck::UnHookPopupMenu(wxMenu* menu, MenuType type)
-{
-    wxUnusedVar(menu);
-    wxUnusedVar(type);
-}
-
 // ------------------------------------------------------------
 void SpellCheck::UnPlug()
 {
-    EventNotifier::Get()->Unbind(wxEVT_CONTEXT_MENU_EDITOR, &SpellCheck::OnEditorContextMenuShowing, this);
     if(m_timer.IsRunning()) m_timer.Stop();
 }
 
@@ -223,8 +246,6 @@ IEditor* SpellCheck::GetEditor()
     IEditor* editor = m_mgr->GetActiveEditor();
 
     if(!editor) {
-        if(GetCheckContinuous()) // switch continuous search off if running
-            SetCheckContinuous(false);
         ::wxMessageBox(s_noEditor, s_codeLite, wxICON_WARNING | wxOK);
         return NULL;
     }
@@ -233,6 +254,8 @@ IEditor* SpellCheck::GetEditor()
 // ------------------------------------------------------------
 void SpellCheck::OnSettings(wxCommandEvent& e)
 {
+    m_pLastEditor = nullptr;
+
     SpellCheckerSettings dlg(m_mgr->GetTheApp()->GetTopWindow());
     dlg.SetHunspell(m_pEngine);
     dlg.SetScanStrings(m_pEngine->IsScannerType(IHunSpell::kString));
@@ -242,6 +265,8 @@ void SpellCheck::OnSettings(wxCommandEvent& e)
     dlg.SetScanD2(m_pEngine->IsScannerType(IHunSpell::kDox2));
     dlg.SetDictionaryFileName(m_pEngine->GetDictionary());
     dlg.SetDictionaryPath(m_pEngine->GetDictionaryPath());
+    dlg.SetCaseSensitiveUserDictionary(m_pEngine->GetCaseSensitiveUserDictionary());
+    dlg.SetIgnoreSymbolsInTagsDatabase(m_pEngine->GetIgnoreSymbolsInTagsDatabase());
 
     if(dlg.ShowModal() == wxID_OK) {
         m_pEngine->EnableScannerType(IHunSpell::kString, dlg.GetScanStrings());
@@ -251,6 +276,8 @@ void SpellCheck::OnSettings(wxCommandEvent& e)
         m_pEngine->EnableScannerType(IHunSpell::kDox2, dlg.GetScanD2());
         m_pEngine->SetDictionaryPath(dlg.GetDictionaryPath());
         m_pEngine->ChangeLanguage(dlg.GetDictionaryFileName());
+        m_pEngine->SetCaseSensitiveUserDictionary(dlg.GetCaseSensitiveUserDictionary());
+        m_pEngine->SetIgnoreSymbolsInTagsDatabase(dlg.GetIgnoreSymbolsInTagsDatabase());
         SaveSettings();
     }
 }
@@ -264,8 +291,10 @@ void SpellCheck::OnCheck(wxCommandEvent& e)
     text += wxT(" "); // prevents indicator flickering at end of file
 
     if(m_pEngine != NULL) {
-        if(GetCheckContinuous()) // switch continuous search off if running
+        if(GetCheckContinuous()) {
+            // switch continuous search off if running
             SetCheckContinuous(false);
+        }
 
         // if we don't have a dictionary yet, open settings
         if(!m_pEngine->GetDictionary()) {
@@ -274,20 +303,16 @@ void SpellCheck::OnCheck(wxCommandEvent& e)
         }
 
         switch(editor->GetLexerId()) {
-        case 3: { // wxSCI_LEX_CPP
+        case wxSTC_LEX_CPP: {
             if(m_mgr->IsWorkspaceOpen()) {
                 m_pEngine->CheckCppSpelling(text);
 
-                if(!m_checkContinuous) {
-                    editor->ClearUserIndicators();
-                }
+                if(!GetCheckContinuous()) { editor->ClearUserIndicators(); }
             }
         } break;
-        case 1: { // wxSCI_LEX_NULL
+        case wxSTC_LEX_NULL: {
             m_pEngine->CheckSpelling(text);
-            if(!m_checkContinuous) {
-                editor->ClearUserIndicators();
-            }
+            if(!GetCheckContinuous()) { editor->ClearUserIndicators(); }
         } break;
         }
     }
@@ -303,6 +328,8 @@ void SpellCheck::LoadSettings()
     m_pEngine->EnableScannerType(IHunSpell::kCComment, m_options.GetScanC());
     m_pEngine->EnableScannerType(IHunSpell::kDox1, m_options.GetScanD1());
     m_pEngine->EnableScannerType(IHunSpell::kDox2, m_options.GetScanD2());
+    m_pEngine->SetCaseSensitiveUserDictionary(m_options.GetCaseSensitiveUserDictionary());
+    m_pEngine->SetIgnoreSymbolsInTagsDatabase(m_options.GetIgnoreSymbolsInTagsDatabase());
 }
 // ------------------------------------------------------------
 void SpellCheck::SaveSettings()
@@ -314,19 +341,13 @@ void SpellCheck::SaveSettings()
     m_options.SetScanC(m_pEngine->IsScannerType(IHunSpell::kCComment));
     m_options.SetScanD1(m_pEngine->IsScannerType(IHunSpell::kDox1));
     m_options.SetScanD2(m_pEngine->IsScannerType(IHunSpell::kDox2));
+    m_options.SetCaseSensitiveUserDictionary(m_pEngine->GetCaseSensitiveUserDictionary());
+    m_options.SetIgnoreSymbolsInTagsDatabase(m_pEngine->GetIgnoreSymbolsInTagsDatabase());
     m_mgr->GetConfigTool()->WriteObject(s_spOptions, &m_options);
 }
 // ------------------------------------------------------------
 void SpellCheck::OnContinousCheck(wxCommandEvent& e)
 {
-    IEditor* editor = m_mgr->GetActiveEditor();
-
-    if(!editor) { // no current editor, switch continuous search off
-
-        SetCheckContinuous(false);
-        return;
-    }
-
     if(m_pEngine != NULL) {
         if(e.GetInt() == 0) {
             SetCheckContinuous(false);
@@ -335,7 +356,6 @@ void SpellCheck::OnContinousCheck(wxCommandEvent& e)
         }
 
         SetCheckContinuous(true);
-        wxString text = editor->GetEditorText();
 
         // if we don't have a dictionary yet, open settings
         if(!m_pEngine->GetDictionary()) {
@@ -343,17 +363,21 @@ void SpellCheck::OnContinousCheck(wxCommandEvent& e)
             return;
         }
 
-        switch(editor->GetLexerId()) {
-        case 3: { // wxSCI_LEX_CPP
-            if(m_mgr->IsWorkspaceOpen()) {
-                m_pEngine->CheckCppSpelling(text);
+        IEditor* editor = m_mgr->GetActiveEditor();
+
+        if(editor) {
+            wxString text = editor->GetEditorText();
+
+            switch(editor->GetLexerId()) {
+            case wxSTC_LEX_CPP: {
+                if(m_mgr->IsWorkspaceOpen()) { m_pEngine->CheckCppSpelling(text); }
+            } break;
+            default: {
+                m_pEngine->CheckSpelling(text);
+            } break;
             }
-        } break;
-        default: { // wxSCI_LEX_NULL
-            m_pEngine->CheckSpelling(text);
-        } break;
+            m_timer.Start(PARSE_TIME);
         }
-        m_timer.Start(PARSE_TIME);
     }
 }
 // ------------------------------------------------------------
@@ -368,114 +392,91 @@ void SpellCheck::OnTimer(wxTimerEvent& e)
     if(!editor) return;
 
     if(GetCheckContinuous()) {
+        // Only run the checks if we've not run them or the file is modified.
+        const auto modificationCount(editor->GetModificationCount());
+        if((editor == m_pLastEditor) && (m_lastModificationCount == modificationCount)) { return; }
+
+        m_pLastEditor = editor;
+        m_lastModificationCount = modificationCount;
+
         switch(editor->GetLexerId()) {
-        case 3: { // wxSCI_LEX_CPP
-            if(m_mgr->IsWorkspaceOpen()) {
-                m_pEngine->CheckCppSpelling(editor->GetEditorText());
-            }
+        case wxSTC_LEX_CPP: {
+            if(m_mgr->IsWorkspaceOpen()) { m_pEngine->CheckCppSpelling(editor->GetEditorText()); }
         } break;
-        default: { // wxSCI_LEX_NULL
+        default: {
             m_pEngine->CheckSpelling(editor->GetEditorText());
         } break;
         }
     }
 }
 // ------------------------------------------------------------
-void SpellCheck::OnContextMenu(wxCommandEvent& e)
-{
-    IEditor* editor = GetEditor();
-
-    if(!editor) {
-        e.Skip();
-        return;
-    }
-
-    wxPoint pt = wxGetMousePosition();
-    pt = editor->GetCtrl()->ScreenToClient(pt);
-    int pos = editor->GetCtrl()->PositionFromPoint(pt);
-
-    if(editor->GetCtrl()->IndicatorValueAt(3, pos) == 1) {
-        wxMenu popUp;
-        m_timer.Stop();
-
-        int start = editor->WordStartPos(pos, true);
-        editor->SelectText(start, editor->WordEndPos(pos, true) - start);
-        wxString sel = editor->GetSelection();
-        wxArrayString sugg = m_pEngine->GetSuggestions(sel);
-
-        for(wxUint32 i = 0; i < sugg.GetCount(); i++) {
-            popUp.Append(SPC_BASEID + i, sugg[i], "");
-        }
-
-        if(sugg.GetCount() == 0)
-            popUp.SetTitle(_("No suggestions"));
-        else
-            popUp.AppendSeparator();
-
-        popUp.Append(SPC_BASEID - 1, _("Ignore"), "");
-        popUp.Append(SPC_BASEID - 2, _("Add"), "");
-
-        int index = editor->GetCtrl()->GetPopupMenuSelectionFromUser(popUp);
-
-        if(index != wxID_NONE) {
-            if(index >= SPC_BASEID) {
-                index -= SPC_BASEID;
-                editor->ReplaceSelection(sugg[index]);
-            } else {
-                if(index == SPC_BASEID - 1)
-                    m_pEngine->AddWordToIgnoreList(sel);
-                else if(index == SPC_BASEID - 2)
-                    m_pEngine->AddWordToUserDict(sel);
-            }
-        }
-        m_timer.Start(PARSE_TIME);
-    } else
-        e.Skip();
-}
-// ------------------------------------------------------------
 void SpellCheck::SetCheckContinuous(bool value)
 {
-    m_checkContinuous = value;
+    m_options.SetCheckContinuous(value);
+    clToolBarButtonBase* btn = clGetManager()->GetToolBar()->FindById(XRCID(s_contCheckID.ToUTF8()));
 
     if(value) {
+        m_pLastEditor = nullptr;
         m_timer.Start(PARSE_TIME);
-        if(m_pToolbar) {
-            m_pToolbar->ToggleTool(XRCID(s_contCheckID.ToUTF8()), true);
-            m_pToolbar->Refresh();
+
+        if(btn) {
+            btn->Check(true);
+            clGetManager()->GetToolBar()->Refresh();
         }
     } else {
         if(m_timer.IsRunning()) m_timer.Stop();
-
-        if(m_pToolbar) {
-            m_pToolbar->ToggleTool(XRCID(s_contCheckID.ToUTF8()), false);
-            m_pToolbar->Refresh();
+        if(btn) {
+            btn->Check(false);
+            clGetManager()->GetToolBar()->Refresh();
         }
     }
 }
 
-// ------------------------------------------------------------
-bool SpellCheck::IsTag(const wxString& token)
-{
-    std::vector<TagEntryPtr> tags;
-    m_mgr->GetTagsManager()->FindSymbol(token, tags);
-    return (tags.size() == 0) ? false : true;
-}
 // ------------------------------------------------------------
 void SpellCheck::OnWspLoaded(wxCommandEvent& e)
 {
     m_currentWspPath = e.GetString();
     e.Skip();
-} // ------------------------------------------------------------
-void SpellCheck::OnWspClosed(wxCommandEvent& e) { e.Skip(); }
-
-void SpellCheck::OnEditorContextMenuShowing(clContextMenuEvent& e)
-{
-    e.Skip();
-    wxMenu* menu = CreateSubMenu();
-    menu->Check(XRCID(s_contCheckID.ToUTF8()), m_checkContinuous);
-    e.GetMenu()->Append(IDM_BASE, _("Spell Checker"), menu);
 }
+// ------------------------------------------------------------
+void SpellCheck::OnWspClosed(wxCommandEvent& e) { e.Skip(); }
+// ------------------------------------------------------------
+void SpellCheck::OnSuggestion(wxCommandEvent& e)
+{
+    const auto editor = GetEditor();
+    if(!editor) { return; }
 
+    const auto pMenu = dynamic_cast<wxMenu*>(e.GetEventObject());
+    if(!pMenu) { return; }
+
+    const auto pMenuItem = pMenu->FindItem(e.GetId());
+    if(!pMenuItem) { return; }
+
+    editor->ReplaceSelection(pMenuItem->GetItemLabel());
+}
+// ------------------------------------------------------------
+void SpellCheck::OnIgnoreWord(wxCommandEvent& e)
+{
+    const auto editor = GetEditor();
+    if(!editor) { return; }
+
+    const auto selection = editor->GetSelection();
+    if(selection.IsEmpty()) { return; }
+
+    m_pEngine->AddWordToIgnoreList(selection);
+}
+// ------------------------------------------------------------
+void SpellCheck::OnAddWord(wxCommandEvent& e)
+{
+    const auto editor = GetEditor();
+    if(!editor) { return; }
+
+    const auto selection = editor->GetSelection();
+    if(selection.IsEmpty()) { return; }
+
+    m_pEngine->AddWordToUserDict(selection);
+}
+// ------------------------------------------------------------
 void SpellCheck::ClearIndicatorsFromEditors()
 {
     // Remove the indicators from all the editors
