@@ -70,7 +70,6 @@ PhpPlugin::PhpPlugin(IManager* manager)
     , m_xdebugLocalsView(NULL)
     , m_xdebugEvalPane(NULL)
     , m_showWelcomePage(false)
-    , m_toggleToolbar(false)
 {
     // Add new workspace type
     clWorkspaceManager::Get().RegisterWorkspace(new PHPWorkspace());
@@ -83,8 +82,6 @@ PhpPlugin::PhpPlugin(IManager* manager)
     PHPWorkspace::Get()->SetPluginManager(m_mgr);
     XDebugManager::Initialize(this);
 
-    // BitmapLoader::RegisterImage(FileExtManager::TypeWorkspacePHP, images.Bitmap("m_bmpPhpWorkspace"));
-
     // Add our UI
     // create tab (possibly detached)
     m_workspaceView = new PHPWorkspaceView(m_mgr->GetWorkspaceView()->GetBook(), m_mgr);
@@ -100,7 +97,7 @@ PhpPlugin::PhpPlugin(IManager* manager)
     // Connect events
     EventNotifier::Get()->Connect(wxEVT_CC_SHOW_QUICK_OUTLINE,
                                   clCodeCompletionEventHandler(PhpPlugin::OnShowQuickOutline), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_DBG_UI_DELTE_ALL_BREAKPOINTS,
+    EventNotifier::Get()->Connect(wxEVT_DBG_UI_DELETE_ALL_BREAKPOINTS,
                                   clDebugEventHandler(PhpPlugin::OnXDebugDeleteAllBreakpoints), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_CMD_CREATE_NEW_WORKSPACE, clCommandEventHandler(PhpPlugin::OnNewWorkspace),
                                   NULL, this);
@@ -124,8 +121,6 @@ PhpPlugin::PhpPlugin(IManager* manager)
                                   wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_CMD_GET_ACTIVE_PROJECT_FILES,
                                   wxCommandEventHandler(PhpPlugin::OnGetActiveProjectFiles), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_CMD_FIND_IN_FILES_DISMISSED,
-                                  clCommandEventHandler(PhpPlugin::OnFindInFilesDismissed), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_PHP_LOAD_URL, PHPEventHandler(PhpPlugin::OnLoadURL), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_ALL_EDITORS_CLOSED, wxCommandEventHandler(PhpPlugin::OnAllEditorsClosed), NULL,
                                   this);
@@ -183,7 +178,7 @@ PhpPlugin::PhpPlugin(IManager* manager)
 #if USE_SFTP
     // Allocate SFTP handler
     m_sftpHandler.reset(new PhpSFTPHandler());
-#endif //USE_SFTP
+#endif // USE_SFTP
 }
 
 PhpPlugin::~PhpPlugin() {}
@@ -196,12 +191,7 @@ bool PhpPlugin::IsWorkspaceViewDetached()
     return detachedPanes.Index(PHPStrings::PHP_WORKSPACE_VIEW_TITLE) != wxNOT_FOUND;
 }
 
-clToolBar* PhpPlugin::CreateToolBar(wxWindow* parent)
-{
-    // Create the toolbar to be used by the plugin
-    clToolBar* tb(NULL);
-    return tb;
-}
+void PhpPlugin::CreateToolBar(clToolBar* toolbar) { wxUnusedVar(toolbar); }
 
 void PhpPlugin::CreatePluginMenu(wxMenu* pluginsMenu)
 {
@@ -214,19 +204,13 @@ void PhpPlugin::HookPopupMenu(wxMenu* menu, MenuType type)
     wxUnusedVar(type);
 }
 
-void PhpPlugin::UnHookPopupMenu(wxMenu* menu, MenuType type)
-{
-    wxUnusedVar(menu);
-    wxUnusedVar(type);
-}
-
 void PhpPlugin::UnPlug()
 {
 #if USE_SFTP
     m_sftpHandler.reset(nullptr);
-#endif //USE_SFTP
+#endif // USE_SFTP
     XDebugManager::Free();
-    EventNotifier::Get()->Disconnect(wxEVT_DBG_UI_DELTE_ALL_BREAKPOINTS,
+    EventNotifier::Get()->Disconnect(wxEVT_DBG_UI_DELETE_ALL_BREAKPOINTS,
                                      clDebugEventHandler(PhpPlugin::OnXDebugDeleteAllBreakpoints), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_CC_SHOW_QUICK_OUTLINE,
                                      clCodeCompletionEventHandler(PhpPlugin::OnShowQuickOutline), NULL, this);
@@ -248,8 +232,6 @@ void PhpPlugin::UnPlug()
                                      this);
     EventNotifier::Get()->Disconnect(wxEVT_CMD_GET_WORKSPACE_FILES,
                                      wxCommandEventHandler(PhpPlugin::OnGetWorkspaceFiles), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_CMD_FIND_IN_FILES_DISMISSED,
-                                     clCommandEventHandler(PhpPlugin::OnFindInFilesDismissed), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_CMD_GET_CURRENT_FILE_PROJECT_FILES,
                                      wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_CMD_GET_ACTIVE_PROJECT_FILES,
@@ -369,7 +351,7 @@ void PhpPlugin::OnOpenWorkspace(clCommandEvent& e)
 {
     e.Skip();
     wxFileName workspaceFile(e.GetFileName());
-    JSONRoot root(workspaceFile);
+    JSON root(workspaceFile);
     if(!root.isOk()) return;
 
     wxString type = root.toElement().namedObject("metadata").namedObject("type").toString();
@@ -564,22 +546,12 @@ void PhpPlugin::OnDebugEnded(XDebugEvent& e)
         m_mgr->GetDockingManager()->LoadPerspective(m_savedPerspective);
         m_savedPerspective.Clear();
     }
-
-    if(m_toggleToolbar) {
-        m_mgr->ShowToolBar(false);
-        m_toggleToolbar = false;
-    }
 }
 
 void PhpPlugin::OnDebugStarted(XDebugEvent& e)
 {
     e.Skip();
     DoEnsureXDebugPanesVisible();
-    m_toggleToolbar = !m_mgr->IsToolBarShown();
-    if(m_toggleToolbar) {
-        // toolbar not shown
-        m_mgr->ShowToolBar();
-    }
 }
 
 void PhpPlugin::OnXDebugDeleteAllBreakpoints(clDebugEvent& e)
@@ -753,16 +725,6 @@ void PhpPlugin::FinalizeStartup()
 
 void PhpPlugin::OnGoingDown(clCommandEvent& event) { event.Skip(); }
 
-void PhpPlugin::OnFindInFilesDismissed(clCommandEvent& e)
-{
-    e.Skip();
-    if(PHPWorkspace::Get()->IsOpen()) {
-        // store the find in files mask
-        PHPConfigurationData conf;
-        conf.Load().SetFindInFilesMask(e.GetString()).Save();
-    }
-}
-
 void PhpPlugin::OnFileSysetmUpdated(clFileSystemEvent& event)
 {
     event.Skip();
