@@ -7,7 +7,7 @@ IMPLEMENT_DYNAMIC_CLASS(MyWxPanelXmlHandler, wxXmlResourceHandler)
 MyWxPanelXmlHandler::MyWxPanelXmlHandler()
     : wxXmlResourceHandler()
 {
-#if WXWIN_COMPATIBILITY_2_6
+#if WXWIN_COMPATIBILITY_2_6 && defined(wxNO_3D)
     XRC_ADD_STYLE(wxNO_3D);
 #endif // WXWIN_COMPATIBILITY_2_6
     XRC_ADD_STYLE(wxTAB_TRAVERSAL);
